searchNodes=[{"ref":"Calendar.AmbiguousDateTime.html","title":"Calendar.AmbiguousDateTime","type":"module","doc":"AmbiguousDateTime provides a struct which represents an ambiguous time and date in a certain time zone. These structs will be returned from the DateTime.from_erl/2 function when the provided time is ambiguous. AmbiguousDateTime contains two DateTime structs. For instance they can represent both a DST and non-DST time. If clocks are turned back an hour at 2:00 when going from summer to winter time then the &quot;wall time&quot; between 1:00 and 2:00 happens twice. One of them is on DST and one of them is not. The provided functions can be used to choose one of the two DateTime structs."},{"ref":"Calendar.AmbiguousDateTime.html#disamb/2","title":"Calendar.AmbiguousDateTime.disamb/2","type":"function","doc":"Disambiguate an AmbiguousDateTime according to filtering function provided as the second parameter Examples We provide a function that returns true if the abbreviation is &quot;-03&quot; iex&gt; {:ambiguous, am} = Calendar.DateTime.from_erl({{2014, 3, 9}, {1, 1, 1}}, &quot;America/Montevideo&quot;); am |&gt; Calendar.AmbiguousDateTime.disamb(fn(dt) -&gt; dt.zone_abbr == &quot;-03&quot; end) {:ok, %DateTime{zone_abbr: &quot;-03&quot;, day: 9, hour: 1, minute: 1, month: 3, second: 1, std_offset: 0, time_zone: &quot;America/Montevideo&quot;, utc_offset: -10800, year: 2014, microsecond: {0, 0}}} A function that always returns false iex&gt; {:ambiguous, am} = Calendar.DateTime.from_erl({{2014, 3, 9}, {1, 1, 1}}, &quot;America/Montevideo&quot;); am |&gt; Calendar.AmbiguousDateTime.disamb(fn(_dt) -&gt; false end) {:error, :no_matches} A function that always returns true iex&gt; {:ambiguous, am} = Calendar.DateTime.from_erl({{2014, 3, 9}, {1, 1, 1}}, &quot;America/Montevideo&quot;); am |&gt; Calendar.AmbiguousDateTime.disamb(fn(_dt) -&gt; true end) {:error, :more_than_one_match}"},{"ref":"Calendar.AmbiguousDateTime.html#disamb_total_off/2","title":"Calendar.AmbiguousDateTime.disamb_total_off/2","type":"function","doc":"Disambiguate an AmbiguousDateTime by total offset. Total offset would be UTC offset plus standard offset. If only one of the possible data times contained in the ambiguous_date_time matches the offset a tuple with :ok and the matching DateTime is returned. Total offset For instance, at the time of this writing, for Berlin there is a 1 hour UTC offset. In the summer, there is another hour of standard offset. This means that in the summer the total offset is 2 hours or 7200 seconds. Examples iex&gt; {:ambiguous, am} = Calendar.DateTime.from_erl({{2014, 3, 9}, {1, 1, 1}}, &quot;America/Montevideo&quot;); am |&gt; Calendar.AmbiguousDateTime.disamb_total_off(-10800) {:ok, %DateTime{zone_abbr: &quot;-03&quot;, day: 9, hour: 1, minute: 1, month: 3, second: 1, std_offset: 0, time_zone: &quot;America/Montevideo&quot;, utc_offset: -10800, year: 2014, microsecond: {0,0}}} iex&gt; {:ambiguous, am} = Calendar.DateTime.from_erl({{2014, 3, 9}, {1, 1, 1}}, &quot;America/Montevideo&quot;); am |&gt; Calendar.AmbiguousDateTime.disamb_total_off(0) {:error, :no_matches}"},{"ref":"Calendar.ContainsDate.html","title":"Calendar.ContainsDate","type":"protocol","doc":""},{"ref":"Calendar.ContainsDate.html#date_struct/1","title":"Calendar.ContainsDate.date_struct/1","type":"function","doc":"Returns a Calendar.Date struct for the struct in question"},{"ref":"Calendar.ContainsDate.html#t:t/0","title":"Calendar.ContainsDate.t/0","type":"type","doc":""},{"ref":"Calendar.ContainsDateTime.html","title":"Calendar.ContainsDateTime","type":"protocol","doc":""},{"ref":"Calendar.ContainsDateTime.html#dt_struct/1","title":"Calendar.ContainsDateTime.dt_struct/1","type":"function","doc":"Returns a Calendar.DateTime struct for the provided data"},{"ref":"Calendar.ContainsDateTime.html#t:t/0","title":"Calendar.ContainsDateTime.t/0","type":"type","doc":""},{"ref":"Calendar.ContainsNaiveDateTime.html","title":"Calendar.ContainsNaiveDateTime","type":"protocol","doc":""},{"ref":"Calendar.ContainsNaiveDateTime.html#ndt_struct/1","title":"Calendar.ContainsNaiveDateTime.ndt_struct/1","type":"function","doc":"Returns a Calendar.NaiveDateTime struct for the provided data"},{"ref":"Calendar.ContainsNaiveDateTime.html#t:t/0","title":"Calendar.ContainsNaiveDateTime.t/0","type":"type","doc":""},{"ref":"Calendar.ContainsTime.html","title":"Calendar.ContainsTime","type":"protocol","doc":""},{"ref":"Calendar.ContainsTime.html#time_struct/1","title":"Calendar.ContainsTime.time_struct/1","type":"function","doc":"Returns a Calendar.Time struct for the provided argument"},{"ref":"Calendar.ContainsTime.html#t:t/0","title":"Calendar.ContainsTime.t/0","type":"type","doc":""},{"ref":"Calendar.Date.html","title":"Calendar.Date","type":"module","doc":"The Date module provides a struct to represent a simple date: year, month and day."},{"ref":"Calendar.Date.html#add/2","title":"Calendar.Date.add/2","type":"function","doc":""},{"ref":"Calendar.Date.html#add!/2","title":"Calendar.Date.add!/2","type":"function","doc":""},{"ref":"Calendar.Date.html#advance/2","title":"Calendar.Date.advance/2","type":"function","doc":"Advances date by days number of days. Examples # Date struct advanced by 3 days iex&gt; from_erl!({2014,12,27}) |&gt; advance(3) {:ok, %Date{day: 30, month: 12, year: 2014} } # Date struct turned back 2 days iex&gt; from_erl!({2014,12,27}) |&gt; advance(-2) {:ok, %Date{day: 25, month: 12, year: 2014} } # Date tuple turned back 2 days iex&gt; {2014,12,27} |&gt; advance(-2) {:ok, %Date{day: 25, month: 12, year: 2014} } # When passing a DateTime, NaiveDateTime or datetime tuple # the time part is ignored. A Date struct is returned. iex&gt; {{2014,12,27}, {21,30,59}} |&gt; Calendar.NaiveDateTime.from_erl! |&gt; advance(-2) {:ok, %Date{day: 25, month: 12, year: 2014} } iex&gt; {{2014,12,27}, {21,30,59}} |&gt; advance(-2) {:ok, %Date{day: 25, month: 12, year: 2014} }"},{"ref":"Calendar.Date.html#advance!/2","title":"Calendar.Date.advance!/2","type":"function","doc":"Like advance/2, but returns the result directly - not tagged with :ok. This function might raise an error. Examples iex&gt; from_erl!({2014,12,27}) |&gt; advance!(3) %Date{day: 30, month: 12, year: 2014} iex&gt; {2014,12,27} |&gt; advance!(-2) %Date{day: 25, month: 12, year: 2014}"},{"ref":"Calendar.Date.html#after?/2","title":"Calendar.Date.after?/2","type":"function","doc":"Returns true if the first date is after the second date iex&gt; from_erl!({2014,12,27}) |&gt; after?(from_erl!({2014,12,20})) true iex&gt; from_erl!({2014,12,27}) |&gt; after?(from_erl!({2014,12,29})) false"},{"ref":"Calendar.Date.html#before?/2","title":"Calendar.Date.before?/2","type":"function","doc":"Returns true if the first date is before the second date iex&gt; from_erl!({2014,12,27}) |&gt; before?(from_erl!({2014,12,20})) false iex&gt; from_erl!({2014,12,27}) |&gt; before?(from_erl!({2014,12,29})) true"},{"ref":"Calendar.Date.html#dates_for_week_number/1","title":"Calendar.Date.dates_for_week_number/1","type":"function","doc":"Like dates_for_week_number/2 but takes a tuple of {year, week_num} instead"},{"ref":"Calendar.Date.html#dates_for_week_number/2","title":"Calendar.Date.dates_for_week_number/2","type":"function","doc":"Takes a year and an ISO week number and returns a list with the dates in that week. iex&gt; dates_for_week_number(2015, 1) [%Date{day: 29, month: 12, year: 2014}, %Date{day: 30, month: 12, year: 2014}, %Date{day: 31, month: 12, year: 2014}, %Date{day: 1, month: 1, year: 2015}, %Date{day: 2, month: 1, year: 2015}, %Date{day: 3, month: 1, year: 2015}, %Date{day: 4, month: 1, year: 2015}] iex&gt; dates_for_week_number(2015, 2) [%Date{day: 5, month: 1, year: 2015}, %Date{day: 6, month: 1, year: 2015}, %Date{day: 7, month: 1, year: 2015}, %Date{day: 8, month: 1, year: 2015}, %Date{day: 9, month: 1, year: 2015}, %Date{day: 10, month: 1, year: 2015}, %Date{day: 11, month: 1, year: 2015}] iex&gt; dates_for_week_number(2015, 53) [%Date{day: 28, month: 12, year: 2015}, %Date{day: 29, month: 12, year: 2015}, %Date{day: 30, month: 12, year: 2015}, %Date{day: 31, month: 12, year: 2015}, %Date{day: 1, month: 1, year: 2016}, %Date{day: 2, month: 1, year: 2016}, %Date{day: 3, month: 1, year: 2016}]"},{"ref":"Calendar.Date.html#day_number_in_year/1","title":"Calendar.Date.day_number_in_year/1","type":"function","doc":"Day number in year for provided date. Examples iex&gt; {2015, 1, 1} |&gt; day_number_in_year 1 iex&gt; {2015, 2, 1} |&gt; day_number_in_year 32 # 2015 has 365 days iex&gt; {2015, 12, 31} |&gt; day_number_in_year 365 # 2000 was leap year and had 366 days iex&gt; {2000, 12, 31} |&gt; day_number_in_year 366"},{"ref":"Calendar.Date.html#day_of_week/1","title":"Calendar.Date.day_of_week/1","type":"function","doc":"Day of the week as an integer. Monday is 1, Tuesday is 2 and so on. ISO-8601. Sunday is 7. Results can be between 1 and 7. See also day_of_week_zb/1 Examples iex&gt; {2015, 7, 6} |&gt; day_of_week # Monday 1 iex&gt; {2015, 7, 7} |&gt; day_of_week # Tuesday 2 iex&gt; {2015, 7, 5} |&gt; day_of_week # Sunday 7"},{"ref":"Calendar.Date.html#day_of_week_name/2","title":"Calendar.Date.day_of_week_name/2","type":"function","doc":"The name of the day of the week as a string. Takes a language code as the second argument. Defaults to :en for English. Examples iex&gt; {2015, 7, 6} |&gt; day_of_week_name # Monday &quot;Monday&quot; iex&gt; {2015, 7, 7} |&gt; day_of_week_name # Tuesday &quot;Tuesday&quot; iex&gt; {2015, 7, 5} |&gt; day_of_week_name # Sunday &quot;Sunday&quot;"},{"ref":"Calendar.Date.html#day_of_week_zb/1","title":"Calendar.Date.day_of_week_zb/1","type":"function","doc":"Day of the week as an integer with Sunday being 0. Monday is 1, Tuesday is 2 and so on. Results can be between 0 and 6. Examples iex&gt; {2015, 7, 5} |&gt; day_of_week_zb # Sunday 0 iex&gt; {2015, 7, 6} |&gt; day_of_week_zb # Monday 1 iex&gt; {2015, 7, 7} |&gt; day_of_week_zb # Tuesday 2"},{"ref":"Calendar.Date.html#days_after/1","title":"Calendar.Date.days_after/1","type":"function","doc":"Stream of dates after the date provided as argument. iex&gt; days_after({2014,12,27}) |&gt; Enum.take(6) [%Date{day: 28, month: 12, year: 2014}, %Date{day: 29, month: 12, year: 2014}, %Date{day: 30, month: 12, year: 2014}, %Date{day: 31, month: 12, year: 2014}, %Date{day: 1, month: 1, year: 2015}, %Date{day: 2, month: 1, year: 2015}]"},{"ref":"Calendar.Date.html#days_after_until/3","title":"Calendar.Date.days_after_until/3","type":"function","doc":"Get a stream of dates. Takes a starting date and an end date. Includes end date. Does not include start date unless true is passed as the third argument. iex&gt; days_after_until({2014,12,27}, {2014,12,29}) |&gt; Enum.to_list [%Date{day: 28, month: 12, year: 2014}, %Date{day: 29, month: 12, year: 2014}] iex&gt; days_after_until({2014,12,27}, {2014,12,29}, true) |&gt; Enum.to_list [%Date{day: 27, month: 12, year: 2014}, %Date{day: 28, month: 12, year: 2014}, %Date{day: 29, month: 12, year: 2014}]"},{"ref":"Calendar.Date.html#days_before/1","title":"Calendar.Date.days_before/1","type":"function","doc":"Stream of dates before the date provided as argument. iex&gt; days_before(from_erl!({2014,12,27})) |&gt; Enum.take(3) [%Date{day: 26, month: 12, year: 2014}, %Date{day: 25, month: 12, year: 2014}, %Date{day: 24, month: 12, year: 2014}]"},{"ref":"Calendar.Date.html#days_before_until/3","title":"Calendar.Date.days_before_until/3","type":"function","doc":"Get a stream of dates going back in time. Takes a starting date and an end date. Includes end date. End date should be before start date. Does not include start date unless true is passed as the third argument. iex&gt; days_before_until({2014,12,27}, {2014,12,24}) |&gt; Enum.to_list [%Date{day: 26, month: 12, year: 2014}, %Date{day: 25, month: 12, year: 2014}, %Date{day: 24, month: 12, year: 2014}] iex&gt; days_before_until({2014,12,27}, {2014,12,24}, false) |&gt; Enum.to_list [%Date{day: 26, month: 12, year: 2014}, %Date{day: 25, month: 12, year: 2014}, %Date{day: 24, month: 12, year: 2014}] iex&gt; days_before_until({2014,12,27}, {2014,12,24}, true) |&gt; Enum.to_list [%Date{day: 27, month: 12, year: 2014}, %Date{day: 26, month: 12, year: 2014}, %Date{day: 25, month: 12, year: 2014}, %Date{day: 24, month: 12, year: 2014}]"},{"ref":"Calendar.Date.html#diff/2","title":"Calendar.Date.diff/2","type":"function","doc":"Difference in days between two dates. Takes two Date structs: first_date and second_date. Subtracts second_date from first_date. iex&gt; from_erl!({2014,12,27}) |&gt; diff(from_erl!({2014,12,20})) 7 iex&gt; from_erl!({2014,12,27}) |&gt; diff(from_erl!({2014,12,29})) -2"},{"ref":"Calendar.Date.html#friday?/1","title":"Calendar.Date.friday?/1","type":"function","doc":"Returns true if the date is a Friday. Examples iex&gt; {2015, 7, 10} |&gt; friday? true iex&gt; {2015, 7, 7} |&gt; friday? false"},{"ref":"Calendar.Date.html#from_erl/1","title":"Calendar.Date.from_erl/1","type":"function","doc":"Takes a erlang style date tuple and returns a tuple with an :ok tag and a Date struct. If the provided date is invalid, it will not be tagged with :ok though as shown below: iex&gt; from_erl({2014,12,27}) {:ok, %Date{day: 27, month: 12, year: 2014}} iex&gt; from_erl({2014,99,99}) {:error, :invalid_date}"},{"ref":"Calendar.Date.html#from_erl!/1","title":"Calendar.Date.from_erl!/1","type":"function","doc":"Like from_erl without the exclamation point, but does not return a tuple with a tag. Instead returns just a Date if valid. Or raises an exception if the provided date is invalid. iex&gt; from_erl! {2014,12,27} %Date{day: 27, month: 12, year: 2014}"},{"ref":"Calendar.Date.html#from_ordinal/2","title":"Calendar.Date.from_ordinal/2","type":"function","doc":"Examples iex&gt; from_ordinal(2015, 1) {:ok, %Date{day: 1, month: 1, year: 2015}} iex&gt; from_ordinal(2015, 270) {:ok, %Date{day: 27, month: 9, year: 2015}} iex&gt; from_ordinal(2015, 999) {:error, :invalid_ordinal_date}"},{"ref":"Calendar.Date.html#from_ordinal!/2","title":"Calendar.Date.from_ordinal!/2","type":"function","doc":"Examples iex&gt; from_ordinal!(2015, 1) %Date{day: 1, month: 1, year: 2015} iex&gt; from_ordinal!(2015, 270) %Date{day: 27, month: 9, year: 2015} iex&gt; from_ordinal!(2015, 365) %Date{day: 31, month: 12, year: 2015}"},{"ref":"Calendar.Date.html#in_week?/3","title":"Calendar.Date.in_week?/3","type":"function","doc":"Takes a date, a year and an ISO week number and returns true if the date is in the week. iex&gt; {2015, 1, 1} |&gt; in_week?(2015, 1) true iex&gt; {2015, 5, 5} |&gt; in_week?(2015, 1) false"},{"ref":"Calendar.Date.html#monday?/1","title":"Calendar.Date.monday?/1","type":"function","doc":"Returns true if the date is a Monday. Examples iex&gt; {2015, 7, 6} |&gt; monday? true iex&gt; {2015, 7, 7} |&gt; monday? false"},{"ref":"Calendar.Date.html#next_day!/1","title":"Calendar.Date.next_day!/1","type":"function","doc":"Takes a Date struct and returns another one representing the next day. iex&gt; from_erl!({2014,12,27}) |&gt; next_day! %Date{day: 28, month: 12, year: 2014} iex&gt; from_erl!({2014,12,31}) |&gt; next_day! %Date{day: 1, month: 1, year: 2015}"},{"ref":"Calendar.Date.html#number_of_days_in_month/1","title":"Calendar.Date.number_of_days_in_month/1","type":"function","doc":"Takes a Date struct and returns the number of days in the month of that date. The day of the date provided does not matter - the result is based on the month and the year. iex&gt; from_erl!({2014,12,27}) |&gt; number_of_days_in_month 31 iex&gt; from_erl!({2015,2,27}) |&gt; number_of_days_in_month 28 iex&gt; from_erl!({2012,2,27}) |&gt; number_of_days_in_month 29"},{"ref":"Calendar.Date.html#prev_day!/1","title":"Calendar.Date.prev_day!/1","type":"function","doc":"Takes a Date struct and returns another one representing the previous day. iex&gt; from_erl!({2014,12,27}) |&gt; prev_day! %Date{day: 26, month: 12, year: 2014}"},{"ref":"Calendar.Date.html#same_date?/2","title":"Calendar.Date.same_date?/2","type":"function","doc":"Takes two variables that contain a date. Returns true if the dates are the same. iex&gt; from_erl!({2014,12,27}) |&gt; same_date?(from_erl!({2014,12,27})) true iex&gt; from_erl!({2014,12,27}) |&gt; same_date?({2014,12,27}) true iex&gt; from_erl!({2014,12,27}) |&gt; same_date?(from_erl!({2014,12,29})) false"},{"ref":"Calendar.Date.html#saturday?/1","title":"Calendar.Date.saturday?/1","type":"function","doc":"Returns true if the date is a Saturday. Examples iex&gt; {2015, 7, 11} |&gt; saturday? true iex&gt; {2015, 7, 7} |&gt; saturday? false"},{"ref":"Calendar.Date.html#subtract/2","title":"Calendar.Date.subtract/2","type":"function","doc":"Subtract days number of days from date. Examples # Date struct turned back 2 days iex&gt; from_erl!({2014,12,27}) |&gt; subtract(2) {:ok, %Date{day: 25, month: 12, year: 2014} } # Date tuple turned back 2 days iex&gt; {2014,12,27} |&gt; subtract(2) {:ok, %Date{day: 25, month: 12, year: 2014} } # When passing a DateTime, Calendar.NaiveDateTime or datetime tuple # the time part is ignored. A Date struct is returned. iex&gt; {{2014,12,27}, {21,30,59}} |&gt; Calendar.NaiveDateTime.from_erl! |&gt; subtract(2) {:ok, %Date{day: 25, month: 12, year: 2014} } iex&gt; {{2014,12,27}, {21,30,59}} |&gt; subtract(2) {:ok, %Date{day: 25, month: 12, year: 2014} }"},{"ref":"Calendar.Date.html#subtract!/2","title":"Calendar.Date.subtract!/2","type":"function","doc":""},{"ref":"Calendar.Date.html#sunday?/1","title":"Calendar.Date.sunday?/1","type":"function","doc":"Returns true if the date is a Sunday. Examples iex&gt; {2015, 7, 12} |&gt; sunday? true iex&gt; {2015, 7, 7} |&gt; sunday? false"},{"ref":"Calendar.Date.html#thursday?/1","title":"Calendar.Date.thursday?/1","type":"function","doc":"Returns true if the date is a Thursday. Examples iex&gt; {2015, 7, 9} |&gt; thursday? true iex&gt; {2015, 7, 7} |&gt; thursday? false"},{"ref":"Calendar.Date.html#to_erl/1","title":"Calendar.Date.to_erl/1","type":"function","doc":"Takes a Date struct and returns an erlang style date tuple."},{"ref":"Calendar.Date.html#to_gregorian_days/1","title":"Calendar.Date.to_gregorian_days/1","type":"function","doc":"Takes a Date struct and returns the number of gregorian days since year 0. iex&gt; from_erl!({2014,12,27}) |&gt; to_gregorian_days 735959"},{"ref":"Calendar.Date.html#to_s/1","title":"Calendar.Date.to_s/1","type":"function","doc":"Returns a string with the date in ISO format. Examples iex&gt; {2015, 7, 12} |&gt; to_s &quot;2015-07-12&quot; iex&gt; {2015, 7, 7} |&gt; to_s &quot;2015-07-07&quot;"},{"ref":"Calendar.Date.html#today!/1","title":"Calendar.Date.today!/1","type":"function","doc":"Returns the date for the time right now in the provided timezone. Examples &gt; today!(&quot;America/Montevideo&quot;) %Date{day: 1, month: 3, year: 2016} &gt; today!(&quot;Australia/Sydney&quot;) %Date{day: 2, month: 3, year: 2016}"},{"ref":"Calendar.Date.html#today_utc/0","title":"Calendar.Date.today_utc/0","type":"function","doc":"Returns the date for the time right now in UTC. Examples &gt; today_utc %Date{day: 1, month: 3, year: 2016}"},{"ref":"Calendar.Date.html#tuesday?/1","title":"Calendar.Date.tuesday?/1","type":"function","doc":"Returns true if the date is a Tuesday. Examples iex&gt; {2015, 7, 6} |&gt; tuesday? false iex&gt; {2015, 7, 7} |&gt; tuesday? true"},{"ref":"Calendar.Date.html#wednesday?/1","title":"Calendar.Date.wednesday?/1","type":"function","doc":"Returns true if the date is a Wednesday. Examples iex&gt; {2015, 7, 8} |&gt; wednesday? true iex&gt; {2015, 7, 9} |&gt; wednesday? false"},{"ref":"Calendar.Date.html#week_number/1","title":"Calendar.Date.week_number/1","type":"function","doc":"Takes a Date struct and returns a tuple with the ISO week number and the year that the week belongs to. Note that the year returned is not always the same as the year provided as an argument. iex&gt; from_erl!({2014, 12, 31}) |&gt; week_number {2015, 1} iex&gt; from_erl!({2014, 12, 27}) |&gt; week_number {2014, 52} iex&gt; from_erl!({2016, 1, 3}) |&gt; week_number {2015, 53}"},{"ref":"Calendar.Date.Format.html","title":"Calendar.Date.Format","type":"module","doc":""},{"ref":"Calendar.Date.Format.html#iso8601/1","title":"Calendar.Date.Format.iso8601/1","type":"function","doc":"Format a date as ISO 8601 extended format Examples iex&gt; {2015, 4, 3} |&gt; iso8601 &quot;2015-04-03&quot;"},{"ref":"Calendar.Date.Format.html#iso8601_basic/1","title":"Calendar.Date.Format.iso8601_basic/1","type":"function","doc":"Format a date as ISO 8601 basic format Examples iex&gt; {2015, 4, 3} |&gt; iso8601_basic &quot;20150403&quot;"},{"ref":"Calendar.Date.Format.html#iso_week_date/1","title":"Calendar.Date.Format.iso_week_date/1","type":"function","doc":"Format a date as ISO 8601 year and week number with weekday. Please not that as with all ISO weekdays the year of the week is not always the same as the year of the date. Examples iex&gt; {2015, 4, 3} |&gt; iso_week_date &quot;2015-W14-5&quot;"},{"ref":"Calendar.Date.Format.html#ordinal/1","title":"Calendar.Date.Format.ordinal/1","type":"function","doc":"Format a date as ISO 8601 ordinal format Examples iex&gt; {2015, 4, 3} |&gt; ordinal &quot;2015-093&quot;"},{"ref":"Calendar.Date.Format.html#week_number/1","title":"Calendar.Date.Format.week_number/1","type":"function","doc":"Make a ISO 8601 week date string for the ISO week that the provided date is in. The string does not have information about the specific date. See also iso_week_date/1 Examples iex&gt; {2015, 4, 3} |&gt; week_number &quot;2015-W14&quot;"},{"ref":"Calendar.Date.Parse.html","title":"Calendar.Date.Parse","type":"module","doc":""},{"ref":"Calendar.Date.Parse.html#iso8601/1","title":"Calendar.Date.Parse.iso8601/1","type":"function","doc":"Parses ISO 8601 date strings. The function accepts both the extended and the basic format. Examples # Extended format iex&gt; iso8601(&quot;2016-01-05&quot;) {:ok, %Date{year: 2016, month: 1, day: 5}} # Basic format (the basic format does not have dashes) iex&gt; iso8601(&quot;20160105&quot;) {:ok, %Date{year: 2016, month: 1, day: 5}} iex&gt; iso8601(&quot;2016-99-05&quot;) {:error, :invalid_date}"},{"ref":"Calendar.Date.Parse.html#iso8601!/1","title":"Calendar.Date.Parse.iso8601!/1","type":"function","doc":"Parses ISO 8601 date strings. Like iso8601/1, but returns the result untagged and raises in case of an error. Examples # Extended format iex&gt; iso8601!(&quot;2016-01-05&quot;) %Date{year: 2016, month: 1, day: 5}"},{"ref":"Calendar.Date.Parse.html#iso_week_date/1","title":"Calendar.Date.Parse.iso_week_date/1","type":"function","doc":"Parses ISO 8601 week date strings. Examples iex&gt; iso_week_date(&quot;2004-W53-6&quot;) {:ok, %Date{year: 2005, month: 1, day: 1}} iex&gt; iso_week_date(&quot;2008-W01-2&quot;) {:ok, %Date{year: 2008, month: 1, day: 1}} iex&gt; iso_week_date(&quot;2004-W53-6D&quot;) {:ok, %Date{year: 2005, month: 1, day: 1}} iex&gt; iso_week_date(&quot;2004-W53-9&quot;) :error iex&gt; iso_week_date(&quot;2004-W54-9&quot;) :error iex&gt; iso_week_date(&quot;2004-W0-9&quot;) :error"},{"ref":"Calendar.Date.Parse.html#iso_week_date!/1","title":"Calendar.Date.Parse.iso_week_date!/1","type":"function","doc":"Parses ISO 8601 week date strings. Like iso_week_date/1 But returns the the result untagged and raises in case of an error. Examples iex&gt; iso_week_date!(&quot;2004-W53-6&quot;) %Date{year: 2005, month: 1, day: 1}"},{"ref":"Calendar.DateTime.html","title":"Calendar.DateTime","type":"module","doc":"DateTime provides a struct which represents a certain time and date in a certain time zone. The functions in this module can be used to create and transform DateTime structs."},{"ref":"Calendar.DateTime.html#add/2","title":"Calendar.DateTime.add/2","type":"function","doc":"Takes a DateTime struct and an integer. Returns a DateTime struct in the future which is greater by the number of seconds found in the seconds argument. NOTE: add/2 ignores leap seconds. The calculation is based on the (wrong) assumption that there are no leap seconds. Examples # Add 2 seconds iex&gt; from_erl!({{2014,10,2},{0,29,10}}, &quot;America/New_York&quot;, 123456) |&gt; add(2) {:ok, %DateTime{zone_abbr: &quot;EDT&quot;, day: 2, hour: 0, minute: 29, month: 10, second: 12, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2014}} # Add 86400 seconds (one day) iex&gt; from_erl!({{2014,10,2},{0,29,10}}, &quot;America/New_York&quot;, 123456) |&gt; add(86400) {:ok, %DateTime{zone_abbr: &quot;EDT&quot;, day: 3, hour: 0, minute: 29, month: 10, second: 10, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2014}} # Add 10 seconds just before DST &quot;spring forward&quot; so we go from 1:59:59 to 3:00:09 iex&gt; from_erl!({{2015,3,8},{1,59,59}}, &quot;America/New_York&quot;, 123456) |&gt; add(10) {:ok, %DateTime{zone_abbr: &quot;EDT&quot;, day: 8, hour: 3, minute: 0, month: 3, second: 9, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2015}} # If you add a negative number of seconds, the resulting datetime will effectively # be subtracted. iex&gt; from_erl!({{2014,10,2},{0,0,0}}, &quot;America/New_York&quot;, 123456) |&gt; add(-200) {:ok, %DateTime{zone_abbr: &quot;EDT&quot;, day: 1, hour: 23, minute: 56, month: 10, second: 40, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2014}}"},{"ref":"Calendar.DateTime.html#add!/2","title":"Calendar.DateTime.add!/2","type":"function","doc":"Takes a DateTime and an integer. Returns the date_time advanced by the number of seconds found in the seconds argument. If seconds is negative, the time is moved back. NOTE: this ignores leap seconds. The calculation is based on the (wrong) assumption that there are no leap seconds. Examples # Add 2 seconds iex&gt; from_erl!({{2014,10,2},{0,29,10}}, &quot;America/New_York&quot;, {123456, 6}) |&gt; add!(2) %DateTime{zone_abbr: &quot;EDT&quot;, day: 2, hour: 0, minute: 29, month: 10, second: 12, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2014} # Add 86400 seconds (one day) iex&gt; from_erl!({{2014,10,2},{0,29,10}}, &quot;America/New_York&quot;, {123456, 6}) |&gt; add!(86400) %DateTime{zone_abbr: &quot;EDT&quot;, day: 3, hour: 0, minute: 29, month: 10, second: 10, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2014} # Add 10 seconds just before DST &quot;spring forward&quot; so we go from 1:59:59 to 3:00:09 iex&gt; from_erl!({{2015,3,8},{1,59,59}}, &quot;America/New_York&quot;, {123456, 6}) |&gt; add!(10) %DateTime{zone_abbr: &quot;EDT&quot;, day: 8, hour: 3, minute: 0, month: 3, second: 9, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2015} # When add a negative integer, the seconds will effectively be subtracted and # the result will be a datetime earlier than the the first argument iex&gt; from_erl!({{2014,10,2},{0,0,0}}, &quot;America/New_York&quot;, {123456, 6}) |&gt; add!(-200) %DateTime{zone_abbr: &quot;EDT&quot;, day: 1, hour: 23, minute: 56, month: 10, second: 40, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2014}"},{"ref":"Calendar.DateTime.html#advance/2","title":"Calendar.DateTime.advance/2","type":"function","doc":"Deprecated version of add/2"},{"ref":"Calendar.DateTime.html#advance!/2","title":"Calendar.DateTime.advance!/2","type":"function","doc":"Deprecated version of add!/2"},{"ref":"Calendar.DateTime.html#after?/2","title":"Calendar.DateTime.after?/2","type":"function","doc":"Takes a two DateTimes and returns true if the first one is greater than the second. Otherwise false. Greater than means that it is later then the second datetime. Examples # The wall times of the two times are the same, but the one in Los Angeles # happens after the one in UTC because Los Angeles is behind UTC iex&gt; from_erl!({{2014,1,1}, {11,11,11}}, &quot;America/Los_Angeles&quot;) |&gt; after?(from_erl!({{2014, 1, 1}, {11, 11, 11}}, &quot;Etc/UTC&quot;)) true iex&gt; from_erl!({{2014,1,1}, {10,10,10}}, &quot;Etc/UTC&quot;) |&gt; after?(from_erl!({{1999, 1, 1}, {11, 11, 11}}, &quot;Etc/UTC&quot;)) true iex&gt; from_erl!({{2014,1,1}, {10,10,10}}, &quot;Etc/UTC&quot;) |&gt; after?(from_erl!({{2020, 1, 1}, {11, 11, 11}}, &quot;Etc/UTC&quot;)) false iex&gt; from_erl!({{2014,1,1}, {10,10,10}}, &quot;Etc/UTC&quot;) |&gt; after?(from_erl!({{2014, 1, 1}, {10, 10, 10}}, &quot;Etc/UTC&quot;)) false"},{"ref":"Calendar.DateTime.html#before?/2","title":"Calendar.DateTime.before?/2","type":"function","doc":"Takes a two DateTimes and returns true if the first one is less than the second. Otherwise false. Less than means that it is earlier then the second datetime. Examples iex&gt; from_erl!({{2014,1,1}, {10,10,10}}, &quot;Etc/UTC&quot;) |&gt; before?(from_erl!({{1999, 1, 1}, {11, 11, 11}}, &quot;Etc/UTC&quot;)) false iex&gt; from_erl!({{2014,1,1}, {10,10,10}}, &quot;Etc/UTC&quot;) |&gt; before?(from_erl!({{2020, 1, 1}, {11, 11, 11}}, &quot;Etc/UTC&quot;)) true iex&gt; from_erl!({{2014,1,1}, {10,10,10}}, &quot;Etc/UTC&quot;) |&gt; before?(from_erl!({{2014, 1, 1}, {10, 10, 10}}, &quot;Etc/UTC&quot;)) false"},{"ref":"Calendar.DateTime.html#diff/2","title":"Calendar.DateTime.diff/2","type":"function","doc":"The difference between two DateTime structs. In seconds and microseconds. Leap seconds are ignored. Returns tuple with {:ok, seconds, microseconds, :before or :after or :same_time} If the first argument is later (e.g. greater) the second, the result will be positive. In case of a negative result the second element (seconds) will be negative. This is always the case if both of the arguments have the microseconds as 0. But if the difference is less than a second and the result is negative, then the microseconds will be negative. Examples # March 30th 2014 02:00:00 in Central Europe the time changed from # winter time to summer time. This means that clocks were set forward # and an hour skipped. So between 01:00 and 4:00 there were 2 hours # not 3. Two hours is 7200 seconds. iex&gt; diff(from_erl!({{2014,3,30},{4,0,0}}, &quot;Europe/Stockholm&quot;), from_erl!({{2014,3,30},{1,0,0}}, &quot;Europe/Stockholm&quot;)) {:ok, 7200, 0, :after} # The first DateTime is 40 seconds after the second DateTime iex&gt; diff(from_erl!({{2014,10,2},{0,29,50}}, &quot;Etc/UTC&quot;), from_erl!({{2014,10,2},{0,29,10}}, &quot;Etc/UTC&quot;)) {:ok, 40, 0, :after} # The first DateTime is 40 seconds before the second DateTime iex&gt; diff(from_erl!({{2014,10,2},{0,29,10}}, &quot;Etc/UTC&quot;), from_erl!({{2014,10,2},{0,29,50}}, &quot;Etc/UTC&quot;)) {:ok, -40, 0, :before} # The first DateTime is 30 microseconds after the second DateTime iex&gt; diff(from_erl!({{2014,10,2},{0,29,0}}, &quot;Etc/UTC&quot;, {31, 5}), from_erl!({{2014,10,2},{0,29,0}}, &quot;Etc/UTC&quot;, {1, 6})) {:ok, 0, 30, :after} # The first DateTime is 2 microseconds after the second DateTime iex&gt; diff(from_erl!({{2014,10,2},{0,29,0}}, &quot;Etc/UTC&quot;, {0, 0}), from_erl!({{2014,10,2},{0,29,0}}, &quot;Etc/UTC&quot;, {2, 6})) {:ok, 0, -2, :before} # The first DateTime is 9.999998 seconds after the second DateTime iex&gt; diff(from_erl!({{2014,10,2},{0,29,10}}, &quot;Etc/UTC&quot;, {0, 0}), from_erl!({{2014,10,2},{0,29,0}}, &quot;Etc/UTC&quot;, {2,6})) {:ok, 9, 999998, :after} # The first DateTime is 9.999998 seconds before the second DateTime iex&gt; diff(from_erl!({{2014,10,2},{0,29,0}}, &quot;Etc/UTC&quot;, {2, 6}), from_erl!({{2014,10,2},{0,29,10}}, &quot;Etc/UTC&quot;, {0, 0})) {:ok, -9, 999998, :before} iex&gt; diff(from_erl!({{2014,10,2},{0,29,0}}, &quot;Etc/UTC&quot;, {0, 0}), from_erl!({{2014,10,2},{0,29,10}}, &quot;Etc/UTC&quot;, {2, 6})) {:ok, -10, 2, :before} iex&gt; diff(from_erl!({{2014,10,2},{0,29,1}}, &quot;Etc/UTC&quot;, {100, 6}), from_erl!({{2014,10,2},{0,29,0}}, &quot;Etc/UTC&quot;, {200, 5})) {:ok, 0, 999900, :after} iex&gt; diff(from_erl!({{2014,10,2},{0,29,0}}, &quot;Etc/UTC&quot;, {10, 5}), from_erl!({{2014,10,2},{0,29,0}}, &quot;Etc/UTC&quot;, {999999, 6})) {:ok, 0, -999989, :before} # 0:29:10.999999 and 0:29:11 should result in -1 microseconds iex&gt; diff(from_erl!({{2014,10,2},{0,29,10}}, &quot;Etc/UTC&quot;, {999999, 6}), from_erl!({{2014,10,2},{0,29,11}}, &quot;Etc/UTC&quot;)) {:ok, 0, -1, :before} iex&gt; diff(from_erl!({{2014,10,2},{0,29,11}}, &quot;Etc/UTC&quot;), from_erl!({{2014,10,2},{0,29,10}}, &quot;Etc/UTC&quot;, {999999, 6})) {:ok, 0, 1, :after}"},{"ref":"Calendar.DateTime.html#from_date_and_time_and_zone/3","title":"Calendar.DateTime.from_date_and_time_and_zone/3","type":"function","doc":"Create new DateTime struct based on a date and a time and a timezone string. Examples iex&gt; from_date_and_time_and_zone({2016, 1, 8}, {14, 10, 55}, &quot;Etc/UTC&quot;) {:ok, %DateTime{day: 8, microsecond: {0, 0}, hour: 14, minute: 10, month: 1, second: 55, year: 2016, zone_abbr: &quot;UTC&quot;, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, std_offset: 0}}"},{"ref":"Calendar.DateTime.html#from_date_and_time_and_zone!/3","title":"Calendar.DateTime.from_date_and_time_and_zone!/3","type":"function","doc":"Like from_date_and_time_and_zone, but returns result untagged and raises in case of an error or ambiguous datetime. Examples iex&gt; from_date_and_time_and_zone!({2016, 1, 8}, {14, 10, 55}, &quot;Etc/UTC&quot;) %DateTime{day: 8, microsecond: {0, 0}, hour: 14, minute: 10, month: 1, second: 55, year: 2016, zone_abbr: &quot;UTC&quot;, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, std_offset: 0}"},{"ref":"Calendar.DateTime.html#from_erl/3","title":"Calendar.DateTime.from_erl/3","type":"function","doc":"Takes an Erlang-style date-time tuple and additionally a timezone name. Returns a tuple with a tag and a DateTime struct. The tag can be :ok, :ambiguous or :error. :ok is for an unambigous time. :ambiguous is for a time that could have different UTC offsets and/or standard offsets. Usually when switching from summer to winter time. An erlang style date-time tuple has the following format: {{year, month, day}, {hour, minute, second}} Examples Normal, non-ambigous time iex&gt; from_erl({{2014, 9, 26}, {17, 10, 20}}, &quot;America/Montevideo&quot;) {:ok, %DateTime{day: 26, hour: 17, minute: 10, month: 9, second: 20, year: 2014, time_zone: &quot;America/Montevideo&quot;, zone_abbr: &quot;-03&quot;, utc_offset: -10800, std_offset: 0, microsecond: {0, 0}} } Switching from summer to wintertime in the fall means an ambigous time. iex&gt; from_erl({{2014, 3, 9}, {1, 1, 1}}, &quot;America/Montevideo&quot;) {:ambiguous, %Calendar.AmbiguousDateTime{possible_date_times: [%DateTime{day: 9, hour: 1, minute: 1, month: 3, second: 1, year: 2014, time_zone: &quot;America/Montevideo&quot;, zone_abbr: &quot;-02&quot;, utc_offset: -10800, std_offset: 3600}, %DateTime{day: 9, hour: 1, minute: 1, month: 3, second: 1, year: 2014, time_zone: &quot;America/Montevideo&quot;, zone_abbr: &quot;-03&quot;, utc_offset: -10800, std_offset: 0}, ]} } iex&gt; from_erl({{2014, 9, 26}, {17, 10, 20}}, &quot;Non-existing timezone&quot;) {:error, :timezone_not_found} The time between 2:00 and 3:00 in the following example does not exist because of the one hour gap caused by switching to DST. iex&gt; from_erl({{2014, 3, 30}, {2, 20, 02}}, &quot;Europe/Copenhagen&quot;) {:error, :invalid_datetime_for_timezone} Time with fractional seconds. This represents the time 17:10:20.987654321 iex&gt; from_erl({{2014, 9, 26}, {17, 10, 20}}, &quot;America/Montevideo&quot;, {987654, 6}) {:ok, %DateTime{day: 26, hour: 17, minute: 10, month: 9, second: 20, year: 2014, time_zone: &quot;America/Montevideo&quot;, zone_abbr: &quot;-03&quot;, utc_offset: -10800, std_offset: 0, microsecond: {987654, 6}} }"},{"ref":"Calendar.DateTime.html#from_erl!/3","title":"Calendar.DateTime.from_erl!/3","type":"function","doc":"Like from_erl/2 without &quot;!&quot;, but returns the result directly without a tag. Will raise if date is ambiguous or invalid! Only use this if you are sure the date is valid. Otherwise use &quot;from_erl&quot; without the &quot;!&quot;. Example: iex&gt; from_erl!({{2014, 9, 26}, {17, 10, 20}}, &quot;America/Montevideo&quot;) %DateTime{day: 26, hour: 17, minute: 10, month: 9, second: 20, year: 2014, time_zone: &quot;America/Montevideo&quot;, zone_abbr: &quot;-03&quot;, utc_offset: -10800, std_offset: 0}"},{"ref":"Calendar.DateTime.html#from_erl_total_off/4","title":"Calendar.DateTime.from_erl_total_off/4","type":"function","doc":"Like from_erl, but also takes an argument with the total UTC offset. (Total offset is standard offset + UTC offset) The result will be the same as from_erl, except if the datetime is ambiguous. When the datetime is ambiguous (for instance during change from DST to non-DST) the total_offset argument is use to try to disambiguise the result. If successful the matching result is returned tagged with :ok. If the total_offset argument does not match either, an error will be returned. Examples: iex&gt; from_erl_total_off({{2014, 9, 26}, {17, 10, 20}}, &quot;America/Montevideo&quot;, -10800, 2) {:ok, %DateTime{day: 26, hour: 17, minute: 10, month: 9, second: 20, year: 2014, time_zone: &quot;America/Montevideo&quot;, zone_abbr: &quot;-03&quot;, utc_offset: -10800, std_offset: 0, microsecond: {2, 6}} } iex&gt; from_erl_total_off({{2014, 3, 9}, {1, 1, 1}}, &quot;America/Montevideo&quot;, -7200, 2) {:ok, %DateTime{day: 9, hour: 1, minute: 1, month: 3, second: 1, year: 2014, time_zone: &quot;America/Montevideo&quot;, microsecond: {2, 6}, zone_abbr: &quot;-02&quot;, utc_offset: -10800, std_offset: 3600} }"},{"ref":"Calendar.DateTime.html#from_erlang_timestamp/1","title":"Calendar.DateTime.from_erlang_timestamp/1","type":"function","doc":"Takes an erlang style 3 touple timestamp with the form: {megasecs, secs, microsecs} This is the form returned by the Erlang function :erlang.timestamp() Examples iex&gt; from_erlang_timestamp({1453, 854322, 799236}) %DateTime{zone_abbr: &quot;UTC&quot;, day: 27, hour: 0, minute: 25, month: 1, second: 22, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, microsecond: {799236, 6}, utc_offset: 0, year: 2016}"},{"ref":"Calendar.DateTime.html#from_micro_erl_total_off/3","title":"Calendar.DateTime.from_micro_erl_total_off/3","type":"function","doc":"Like from_erl_total_off/4 but takes a 7 element datetime tuple with microseconds instead of a &quot;normal&quot; erlang style tuple. Examples: iex&gt; from_micro_erl_total_off({{2014, 3, 9}, {1, 1, 1, 2}}, &quot;America/Montevideo&quot;, -7200) {:ok, %DateTime{day: 9, hour: 1, minute: 1, month: 3, second: 1, year: 2014, time_zone: &quot;America/Montevideo&quot;, microsecond: {2, 6}, zone_abbr: &quot;-02&quot;, utc_offset: -10800, std_offset: 3600} }"},{"ref":"Calendar.DateTime.html#from_naive/2","title":"Calendar.DateTime.from_naive/2","type":"function","doc":"Takes an NaiveDateTime and a time zone identifier and returns a DateTime iex&gt; Calendar.NaiveDateTime.from_erl!({{2014,10,15},{2,37,22}}) |&gt; from_naive(&quot;Etc/UTC&quot;) {:ok, %DateTime{zone_abbr: &quot;UTC&quot;, day: 15, microsecond: {0, 0}, hour: 2, minute: 37, month: 10, second: 22, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2014}} iex&gt; Calendar.NaiveDateTime.from_erl!({{2014,10,15},{2,37,22}}, {13, 6}) |&gt; from_naive(&quot;Etc/UTC&quot;) {:ok, %DateTime{zone_abbr: &quot;UTC&quot;, day: 15, microsecond: {13, 6}, hour: 2, minute: 37, month: 10, second: 22, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2014}}"},{"ref":"Calendar.DateTime.html#gregorian_seconds/1","title":"Calendar.DateTime.gregorian_seconds/1","type":"function","doc":"Takes a DateTime and returns an integer of gregorian seconds starting with year 0. This is done via the Erlang calendar module. Examples iex&gt; from_erl!({{2014,9,26},{17,10,20}}, &quot;UTC&quot;) |&gt; gregorian_seconds 63578970620"},{"ref":"Calendar.DateTime.html#gregorian_seconds_and_microsecond/1","title":"Calendar.DateTime.gregorian_seconds_and_microsecond/1","type":"function","doc":""},{"ref":"Calendar.DateTime.html#now/1","title":"Calendar.DateTime.now/1","type":"function","doc":"Takes a timezone name and returns a DateTime with the current time in that timezone. The result is returned in a tuple tagged with :ok iex &gt; Calendar.DateTime.now! &quot;Europe/Copenhagen&quot; {:ok, %DateTime{zone_abbr: &quot;CEST&quot;, day: 15, hour: 4, minute: 41, month: 10, second: 1, std_offset: 3600, time_zone: &quot;Europe/Copenhagen&quot;, utc_offset: 3600, year: 2014}} iex&gt; Calendar.DateTime.now &quot;Invalid/Narnia&quot; :error"},{"ref":"Calendar.DateTime.html#now!/1","title":"Calendar.DateTime.now!/1","type":"function","doc":"Takes a timezone name and returns a DateTime with the current time in that timezone. Timezone names must be in the TZ data format. Raises in case of an incorrect time zone name. Examples iex &gt; Calendar.DateTime.now! &quot;UTC&quot; %DateTime{zone_abbr: &quot;UTC&quot;, day: 15, hour: 2, minute: 39, month: 10, second: 53, std_offset: 0, time_zone: &quot;UTC&quot;, utc_offset: 0, year: 2014} iex &gt; Calendar.DateTime.now! &quot;Europe/Copenhagen&quot; %DateTime{zone_abbr: &quot;CEST&quot;, day: 15, hour: 4, minute: 41, month: 10, second: 1, std_offset: 3600, time_zone: &quot;Europe/Copenhagen&quot;, utc_offset: 3600, year: 2014}"},{"ref":"Calendar.DateTime.html#now_utc/0","title":"Calendar.DateTime.now_utc/0","type":"function","doc":"Like DateTime.now!(&quot;Etc/UTC&quot;)"},{"ref":"Calendar.DateTime.html#same_time?/2","title":"Calendar.DateTime.same_time?/2","type":"function","doc":"Takes a two DateTimes and returns true if the first is at the same time as the second one. Examples iex&gt; from_erl!({{2014,1,1}, {10,10,10}}, &quot;Etc/UTC&quot;) |&gt; same_time?(from_erl!({{2014, 1, 1}, {10, 10, 10}}, &quot;Etc/UTC&quot;)) true # 10:00 in London is the same time as 11:00 in Copenhagen iex&gt; from_erl!({{2014,1,1}, {10,10,10}}, &quot;Europe/London&quot;) |&gt; same_time?(from_erl!({{2014, 1, 1}, {11, 10, 10}}, &quot;Europe/Copenhagen&quot;)) true iex&gt; from_erl!({{2014,1,1}, {10,10,10}}, &quot;America/Godthab&quot;) |&gt; same_time?(from_erl!({{2014, 1, 1}, {10, 10, 10}}, &quot;Etc/UTC&quot;)) false iex&gt; from_erl!({{2014,1,1}, {10,10,10}}, &quot;Etc/UTC&quot;) |&gt; same_time?(from_erl!({{2020, 1, 1}, {11, 11, 11}}, &quot;Etc/UTC&quot;)) false iex&gt; from_erl!({{2014,1,1}, {10,10,10}}, &quot;Europe/London&quot;) |&gt; same_time?(from_erl!({{2014, 1, 1}, {10, 10, 10}}, &quot;Etc/UTC&quot;)) true"},{"ref":"Calendar.DateTime.html#shift_zone/2","title":"Calendar.DateTime.shift_zone/2","type":"function","doc":"Takes a DateTime and the name of a new timezone. Returns a DateTime with the equivalent time in the new timezone. Examples iex&gt; from_erl!({{2014,10,2},{0,29,10}}, &quot;America/New_York&quot;,123456) |&gt; shift_zone(&quot;Europe/Copenhagen&quot;) {:ok, %DateTime{zone_abbr: &quot;CEST&quot;, day: 2, hour: 6, minute: 29, month: 10, second: 10, time_zone: &quot;Europe/Copenhagen&quot;, utc_offset: 3600, std_offset: 3600, year: 2014, microsecond: {123456, 6}}} iex&gt; {:ok, nyc} = from_erl {{2014,10,2},{0,29,10}},&quot;America/New_York&quot;; shift_zone(nyc, &quot;Invalid timezone&quot;) {:invalid_time_zone, nil}"},{"ref":"Calendar.DateTime.html#shift_zone!/2","title":"Calendar.DateTime.shift_zone!/2","type":"function","doc":"Like shift_zone without &quot;!&quot;, but does not check that the time zone is valid and just returns a DateTime struct instead of a tuple with a tag. Example iex&gt; from_erl!({{2014,10,2},{0,29,10}},&quot;America/New_York&quot;) |&gt; shift_zone!(&quot;Europe/Copenhagen&quot;) %DateTime{zone_abbr: &quot;CEST&quot;, day: 2, hour: 6, minute: 29, month: 10, second: 10, time_zone: &quot;Europe/Copenhagen&quot;, utc_offset: 3600, std_offset: 3600, year: 2014}"},{"ref":"Calendar.DateTime.html#subtract/2","title":"Calendar.DateTime.subtract/2","type":"function","doc":"Takes a DateTime struct and an integer. Subtracts the number of seconds found in the seconds argument. NOTE: subtract/2 ignores leap seconds. The calculation is based on the (wrong) assumption that there are no leap seconds. See TimeZoneData.leap_seconds/0 function for a list of past leap seconds. Examples # Go back 62 seconds iex&gt; from_erl!({{2014,10,2},{0,0,0}}, &quot;America/New_York&quot;, 123456) |&gt; subtract(62) {:ok, %DateTime{zone_abbr: &quot;EDT&quot;, day: 1, hour: 23, minute: 58, month: 10, second: 58, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2014}} # Go back too far so that year would be before 0 iex&gt; from_erl!({{2014,10,2},{0,0,0}}, &quot;America/New_York&quot;, 123456) |&gt; subtract(999999999999) {:error, :function_clause_error} # Using a negative amount of seconds with the subtract/2 means effectively adding the absolute amount of seconds iex&gt; from_erl!({{2014,10,2},{0,0,0}}, &quot;America/New_York&quot;, 123456) |&gt; subtract!(-200) %DateTime{zone_abbr: &quot;EDT&quot;, day: 2, hour: 0, minute: 3, month: 10, second: 20, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2014}"},{"ref":"Calendar.DateTime.html#subtract!/2","title":"Calendar.DateTime.subtract!/2","type":"function","doc":"Takes a DateTime struct and an integer. Returns a DateTime struct in the past which is less by the number of seconds found in the seconds argument. NOTE: subtract!/2 ignores leap seconds. The calculation is based on the (wrong) assumption that there are no leap seconds. See Calendar.TimeZoneData.leap_seconds/0 function for a list of past leap seconds. Examples # Go back 62 seconds iex&gt; from_erl!({{2014,10,2},{0,0,0}}, &quot;America/New_York&quot;, {123456, 6}) |&gt; subtract!(62) %DateTime{zone_abbr: &quot;EDT&quot;, day: 1, hour: 23, minute: 58, month: 10, second: 58, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2014} # Go back too far so that year would be before 0 iex&gt; from_erl!({{2014,10,2},{0,0,0}}, &quot;America/New_York&quot;, {123456, 6}) |&gt; subtract!(999999999999) ** (MatchError) no match of right hand side value: {:error, :function_clause_error} # Using a negative amount of seconds with the subtract/2 means effectively adding the absolute amount of seconds iex&gt; from_erl!({{2014,10,2},{0,0,0}}, &quot;America/New_York&quot;, {123456, 6}) |&gt; subtract!(-200) %DateTime{zone_abbr: &quot;EDT&quot;, day: 2, hour: 0, minute: 3, month: 10, second: 20, std_offset: 3600, time_zone: &quot;America/New_York&quot;, microsecond: {123456, 6}, utc_offset: -18000, year: 2014}"},{"ref":"Calendar.DateTime.html#to_date/1","title":"Calendar.DateTime.to_date/1","type":"function","doc":"Takes a DateTime struct and returns a Date struct representing the date part of the provided DateTime. iex&gt; from_erl!({{2014,10,15},{2,37,22}}, &quot;UTC&quot;) |&gt; Calendar.DateTime.to_date %Date{day: 15, month: 10, year: 2014}"},{"ref":"Calendar.DateTime.html#to_date_and_time/1","title":"Calendar.DateTime.to_date_and_time/1","type":"function","doc":"Returns a tuple with a Date struct and a Time struct. iex&gt; from_erl!({{2014,10,15},{2,37,22}}, &quot;UTC&quot;) |&gt; Calendar.DateTime.to_date_and_time {%Date{day: 15, month: 10, year: 2014}, %Time{microsecond: {0, 0}, hour: 2, minute: 37, second: 22}}"},{"ref":"Calendar.DateTime.html#to_erl/1","title":"Calendar.DateTime.to_erl/1","type":"function","doc":"Takes a DateTime struct and returns an erlang style datetime tuple. Examples iex&gt; from_erl!({{2014,10,15},{2,37,22}}, &quot;Etc/UTC&quot;) |&gt; Calendar.DateTime.to_erl {{2014, 10, 15}, {2, 37, 22}}"},{"ref":"Calendar.DateTime.html#to_micro_erl/1","title":"Calendar.DateTime.to_micro_erl/1","type":"function","doc":"Takes a DateTime struct and returns an Ecto style datetime tuple. This is like an erlang style tuple, but with microseconds added as an additional element in the time part of the tuple. Examples iex&gt; from_erl!({{2014,10,15},{2,37,22}}, &quot;Etc/UTC&quot;, {999999, 6}) |&gt; Calendar.DateTime.to_micro_erl {{2014, 10, 15}, {2, 37, 22, 999999}} iex&gt; from_erl!({{2014,10,15},{2,37,22}}, &quot;Etc/UTC&quot;, {0, 0}) |&gt; Calendar.DateTime.to_micro_erl {{2014, 10, 15}, {2, 37, 22, 0}}"},{"ref":"Calendar.DateTime.html#to_naive/1","title":"Calendar.DateTime.to_naive/1","type":"function","doc":"Takes a DateTime and returns a NaiveDateTime iex&gt; Calendar.DateTime.from_erl!({{2014,10,15},{2,37,22}}, &quot;UTC&quot;, 55) |&gt; to_naive %NaiveDateTime{day: 15, microsecond: {55, 6}, hour: 2, minute: 37, month: 10, second: 22, year: 2014}"},{"ref":"Calendar.DateTime.html#to_time/1","title":"Calendar.DateTime.to_time/1","type":"function","doc":"Takes a DateTime struct and returns a Time struct representing the time part of the provided DateTime. iex&gt; from_erl!({{2014,10,15},{2,37,22}}, &quot;UTC&quot;) |&gt; Calendar.DateTime.to_time %Time{microsecond: {0, 0}, hour: 2, minute: 37, second: 22}"},{"ref":"Calendar.DateTime.Format.html","title":"Calendar.DateTime.Format","type":"module","doc":""},{"ref":"Calendar.DateTime.Format.html#httpdate/1","title":"Calendar.DateTime.Format.httpdate/1","type":"function","doc":"Takes a DateTime. Returns a string with the date-time in RFC 2616 format. This format is used in the HTTP protocol. Note that the date-time will always be &quot;shifted&quot; to UTC. Example # The time is 6:09 in the morning in Montevideo, but 9:09 GMT/UTC. iex&gt; Calendar.DateTime.from_erl!({{2014, 9, 6}, {6, 9, 8}}, &quot;America/Montevideo&quot;) |&gt; Calendar.DateTime.Format.httpdate &quot;Sat, 06 Sep 2014 09:09:08 GMT&quot;"},{"ref":"Calendar.DateTime.Format.html#iso8601/1","title":"Calendar.DateTime.Format.iso8601/1","type":"function","doc":"Format as ISO 8601 extended (alias for rfc3339/1)"},{"ref":"Calendar.DateTime.Format.html#iso8601_basic/1","title":"Calendar.DateTime.Format.iso8601_basic/1","type":"function","doc":"Format as ISO 8601 Basic Examples iex&gt; Calendar.DateTime.from_erl!({{2014, 9, 26}, {20, 10, 20}}, &quot;Etc/UTC&quot;,5) |&gt; Calendar.DateTime.Format.iso8601_basic &quot;20140926T201020Z&quot; iex&gt; Calendar.DateTime.from_erl!({{2014, 9, 26}, {17, 10, 20}}, &quot;America/Montevideo&quot;,5) |&gt; Calendar.DateTime.Format.iso8601_basic &quot;20140926T171020-0300&quot;"},{"ref":"Calendar.DateTime.Format.html#js_ms/1","title":"Calendar.DateTime.Format.js_ms/1","type":"function","doc":"Takes datetime and returns UTC timestamp in JavaScript format. That is milliseconds since 1970 unix epoch. These millisecond numbers can be used to create new Javascript Dates in JavaScript like so: new Date(1000000000985) The UTC value of the javascript date will be the same as that of the Elixir Calendar.DateTime. Examples iex&gt; Calendar.DateTime.from_erl!({{2001,09,09},{03,46,40}}, &quot;Europe/Copenhagen&quot;, 985085) |&gt; Calendar.DateTime.Format.js_ms 1000000000985 iex&gt; Calendar.DateTime.from_erl!({{2001,09,09},{03,46,40}}, &quot;Europe/Copenhagen&quot;, 98508) |&gt; Calendar.DateTime.Format.js_ms 1000000000098"},{"ref":"Calendar.DateTime.Format.html#rfc2822/1","title":"Calendar.DateTime.Format.rfc2822/1","type":"function","doc":"Format a DateTime as an RFC 2822 timestamp. Examples iex&gt; Calendar.DateTime.from_erl!({{2010, 3, 13}, {11, 23, 03}}, &quot;America/Los_Angeles&quot;) |&gt; rfc2822 &quot;Sat, 13 Mar 2010 11:23:03 -0800&quot; iex&gt; Calendar.DateTime.from_erl!({{2010, 3, 13}, {11, 23, 03}}, &quot;Etc/UTC&quot;) |&gt; rfc2822 &quot;Sat, 13 Mar 2010 11:23:03 +0000&quot;"},{"ref":"Calendar.DateTime.Format.html#rfc3339/1","title":"Calendar.DateTime.Format.rfc3339/1","type":"function","doc":"Takes a DateTime. Returns a string with the time in RFC3339 (a profile of ISO 8601) Examples Without microseconds iex&gt; Calendar.DateTime.from_erl!({{2014, 9, 26}, {17, 10, 20}}, &quot;America/Montevideo&quot;) |&gt; Calendar.DateTime.Format.rfc3339 &quot;2014-09-26T17:10:20-03:00&quot; With microseconds iex&gt; Calendar.DateTime.from_erl!({{2014, 9, 26}, {17, 10, 20, 5}}, &quot;America/Montevideo&quot;) |&gt; Calendar.DateTime.Format.rfc3339 &quot;2014-09-26T17:10:20.000005-03:00&quot;"},{"ref":"Calendar.DateTime.Format.html#rfc3339/2","title":"Calendar.DateTime.Format.rfc3339/2","type":"function","doc":"Takes a DateTime and a integer for number of decimals. Returns a string with the time in RFC3339 (a profile of ISO 8601) The decimal_count integer defines the number fractional second digits. The decimal_count must be between 0 and 6. Fractional seconds are not rounded up, but rather trucated. Examples DateTime does not have microseconds, but 3 digits of fractional seconds requested. We assume 0 microseconds and display three zeroes. iex&gt; Calendar.DateTime.from_erl!({{2014, 9, 26}, {17, 10, 20}}, &quot;America/Montevideo&quot;) |&gt; Calendar.DateTime.Format.rfc3339(3) &quot;2014-09-26T17:10:20.000-03:00&quot; DateTime has microseconds and decimal count set to 6 iex&gt; Calendar.DateTime.from_erl!({{2014, 9, 26}, {17, 10, 20}}, &quot;America/Montevideo&quot;,{5, 6}) |&gt; Calendar.DateTime.Format.rfc3339(6) &quot;2014-09-26T17:10:20.000005-03:00&quot; DateTime has microseconds and decimal count set to 5 iex&gt; Calendar.DateTime.from_erl!({{2014, 9, 26}, {17, 10, 20}}, &quot;America/Montevideo&quot;,{5, 6}) |&gt; Calendar.DateTime.Format.rfc3339(5) &quot;2014-09-26T17:10:20.00000-03:00&quot; DateTime has microseconds and decimal count set to 0 iex&gt; Calendar.DateTime.from_erl!({{2014, 9, 26}, {17, 10, 20}}, &quot;America/Montevideo&quot;,{5, 6}) |&gt; Calendar.DateTime.Format.rfc3339(0) &quot;2014-09-26T17:10:20-03:00&quot;"},{"ref":"Calendar.DateTime.Format.html#rfc822/1","title":"Calendar.DateTime.Format.rfc822/1","type":"function","doc":"Format a DateTime as an RFC 822 timestamp. Note that this format is old and uses only 2 digits to denote the year! Examples iex&gt; Calendar.DateTime.from_erl!({{2010, 3, 13}, {11, 23, 03}}, &quot;America/Los_Angeles&quot;) |&gt; rfc822 &quot;Sat, 13 Mar 10 11:23:03 -0800&quot; iex&gt; Calendar.DateTime.from_erl!({{2010, 3, 13}, {11, 23, 03}}, &quot;Etc/UTC&quot;) |&gt; rfc822 &quot;Sat, 13 Mar 10 11:23:03 +0000&quot;"},{"ref":"Calendar.DateTime.Format.html#rfc850/1","title":"Calendar.DateTime.Format.rfc850/1","type":"function","doc":"Format a DateTime as an RFC 850 timestamp. Note that this format is old and uses only 2 digits to denote the year! Examples iex&gt; Calendar.DateTime.from_erl!({{2010, 3, 13}, {11, 23, 03}}, &quot;America/Los_Angeles&quot;) |&gt; rfc850 &quot;Sat, 13-Mar-10 11:23:03 PST&quot;"},{"ref":"Calendar.DateTime.Format.html#unix/1","title":"Calendar.DateTime.Format.unix/1","type":"function","doc":"Unix time. Unix time is defined as seconds since 1970-01-01 00:00:00 UTC without leap seconds. Examples iex&gt; Calendar.DateTime.from_erl!({{2001,09,09},{03,46,40}}, &quot;Europe/Copenhagen&quot;, {55, 2}) |&gt; Calendar.DateTime.Format.unix 1_000_000_000"},{"ref":"Calendar.DateTime.Format.html#unix_micro/1","title":"Calendar.DateTime.Format.unix_micro/1","type":"function","doc":"Like unix_time but returns a float with fractional seconds. If the microsecond of the DateTime is nil, the fractional seconds will be treated as 0.0 as seen in the second example below: Examples iex&gt; Calendar.DateTime.from_erl!({{2001,09,09},{03,46,40}}, &quot;Europe/Copenhagen&quot;, {985085, 6}) |&gt; Calendar.DateTime.Format.unix_micro 1_000_000_000.985085 iex&gt; Calendar.DateTime.from_erl!({{2001,09,09},{03,46,40}}, &quot;Europe/Copenhagen&quot;) |&gt; Calendar.DateTime.Format.unix_micro 1_000_000_000.0"},{"ref":"Calendar.DateTime.Interval.html","title":"Calendar.DateTime.Interval","type":"module","doc":"An Interval consists of a start and an end DateTime."},{"ref":"Calendar.DateTime.Interval.html#includes?/2","title":"Calendar.DateTime.Interval.includes?/2","type":"function","doc":"Returns true when the interval contains the given datetime. &quot;From&quot; and &quot;to&quot; datetimes are treated as inclusive. This means that if the provided datetime is between the from and to of the interval or equal to either, true will be returned."},{"ref":"Calendar.DateTime.Interval.html#t:t/0","title":"Calendar.DateTime.Interval.t/0","type":"type","doc":""},{"ref":"Calendar.DateTime.Parse.html","title":"Calendar.DateTime.Parse","type":"module","doc":""},{"ref":"Calendar.DateTime.Parse.html#httpdate/1","title":"Calendar.DateTime.Parse.httpdate/1","type":"function","doc":"Parses a timestamp in RFC 2616 format. iex&gt; httpdate(&quot;Sat, 06 Sep 2014 09:09:08 GMT&quot;) {:ok, %DateTime{year: 2014, month: 9, day: 6, hour: 9, minute: 9, second: 8, time_zone: &quot;Etc/UTC&quot;, zone_abbr: &quot;UTC&quot;, std_offset: 0, utc_offset: 0, microsecond: {0, 0}}} iex&gt; httpdate(&quot;invalid&quot;) {:bad_format, nil} iex&gt; httpdate(&quot;Foo, 06 Foo 2014 09:09:08 GMT&quot;) {:error, :invalid_datetime}"},{"ref":"Calendar.DateTime.Parse.html#httpdate!/1","title":"Calendar.DateTime.Parse.httpdate!/1","type":"function","doc":"Like httpdate/1, but returns the result without tagging it with :ok in case of success. In case of errors it raises. iex&gt; httpdate!(&quot;Sat, 06 Sep 2014 09:09:08 GMT&quot;) %DateTime{year: 2014, month: 9, day: 6, hour: 9, minute: 9, second: 8, time_zone: &quot;Etc/UTC&quot;, zone_abbr: &quot;UTC&quot;, std_offset: 0, utc_offset: 0}"},{"ref":"Calendar.DateTime.Parse.html#js_ms!/1","title":"Calendar.DateTime.Parse.js_ms!/1","type":"function","doc":"Parse JavaScript style milliseconds since epoch. Examples iex&gt; js_ms!(&quot;1000000000123&quot;) %DateTime{zone_abbr: &quot;UTC&quot;, day: 9, microsecond: {123000,3}, hour: 1, minute: 46, month: 9, second: 40, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2001} iex&gt; js_ms!(1_000_000_000_123) %DateTime{zone_abbr: &quot;UTC&quot;, day: 9, microsecond: {123000,3}, hour: 1, minute: 46, month: 9, second: 40, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2001} iex&gt; js_ms!(1424102000000) %DateTime{zone_abbr: &quot;UTC&quot;, day: 16, hour: 15, microsecond: {0, 3}, minute: 53, month: 2, second: 20, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2015}"},{"ref":"Calendar.DateTime.Parse.html#rfc2822_utc/1","title":"Calendar.DateTime.Parse.rfc2822_utc/1","type":"function","doc":"Parses an RFC 2822 or RFC 1123 datetime string. The datetime is shifted to UTC. Examples iex&gt; rfc2822_utc(&quot;Sat, 13 Mar 2010 11:23:03 -0800&quot;) {:ok, %DateTime{zone_abbr: &quot;UTC&quot;, day: 13, hour: 19, minute: 23, month: 3, second: 3, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, microsecond: {0, 0}, utc_offset: 0, year: 2010}} # PST is the equivalent of -0800 in the RFC 2822 standard iex&gt; rfc2822_utc(&quot;Sat, 13 Mar 2010 11:23:03 PST&quot;) {:ok, %DateTime{zone_abbr: &quot;UTC&quot;, day: 13, hour: 19, minute: 23, month: 3, second: 3, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, microsecond: {0, 0}, utc_offset: 0, year: 2010}} # Z is the equivalent of UTC iex&gt; rfc2822_utc(&quot;Sat, 13 Mar 2010 11:23:03 Z&quot;) {:ok, %DateTime{zone_abbr: &quot;UTC&quot;, day: 13, hour: 11, minute: 23, month: 3, second: 3, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, microsecond: {0, 0}, utc_offset: 0, year: 2010}}"},{"ref":"Calendar.DateTime.Parse.html#rfc3339/2","title":"Calendar.DateTime.Parse.rfc3339/2","type":"function","doc":"Parses an RFC 3339 timestamp and shifts it to the specified time zone. iex&gt; rfc3339(&quot;1996-12-19T16:39:57Z&quot;, &quot;Etc/UTC&quot;) {:ok, %DateTime{year: 1996, month: 12, day: 19, hour: 16, minute: 39, second: 57, time_zone: &quot;Etc/UTC&quot;, zone_abbr: &quot;UTC&quot;, std_offset: 0, utc_offset: 0}} iex&gt; rfc3339(&quot;1996-12-19T16:39:57.1234Z&quot;, &quot;Etc/UTC&quot;) {:ok, %DateTime{year: 1996, month: 12, day: 19, hour: 16, minute: 39, second: 57, time_zone: &quot;Etc/UTC&quot;, zone_abbr: &quot;UTC&quot;, std_offset: 0, utc_offset: 0, microsecond: {123400, 4}}} iex&gt; rfc3339(&quot;1996-12-19T16:39:57-8:00&quot;, &quot;America/Los_Angeles&quot;) {:ok, %DateTime{zone_abbr: &quot;PST&quot;, day: 19, hour: 16, minute: 39, month: 12, second: 57, std_offset: 0, time_zone: &quot;America/Los_Angeles&quot;, utc_offset: -28800, year: 1996}} iex&gt; rfc3339(&quot;1996-12-19T16:39:57.1234-8:00&quot;, &quot;America/Los_Angeles&quot;) {:ok, %DateTime{zone_abbr: &quot;PST&quot;, day: 19, hour: 16, minute: 39, month: 12, second: 57, std_offset: 0, time_zone: &quot;America/Los_Angeles&quot;, utc_offset: -28800, year: 1996, microsecond: {123400, 4}}} iex&gt; rfc3339(&quot;invalid&quot;, &quot;America/Los_Angeles&quot;) {:bad_format, nil} iex&gt; rfc3339(&quot;1996-12-19T16:39:57-08:00&quot;, &quot;invalid time zone name&quot;) {:invalid_time_zone, nil}"},{"ref":"Calendar.DateTime.Parse.html#rfc3339_utc/1","title":"Calendar.DateTime.Parse.rfc3339_utc/1","type":"function","doc":"Parse RFC 3339 timestamp strings as UTC. If the timestamp is not in UTC it will be shifted to UTC. Examples iex&gt; rfc3339_utc(&quot;fooo&quot;) {:bad_format, nil} iex&gt; rfc3339_utc(&quot;1996-12-19T16:39:57&quot;) {:bad_format, nil} iex&gt; rfc3339_utc(&quot;1996-12-19T16:39:57Z&quot;) {:ok, %DateTime{year: 1996, month: 12, day: 19, hour: 16, minute: 39, second: 57, time_zone: &quot;Etc/UTC&quot;, zone_abbr: &quot;UTC&quot;, std_offset: 0, utc_offset: 0}} iex&gt; rfc3339_utc(&quot;1996-12-19T16:39:57.123Z&quot;) {:ok, %DateTime{year: 1996, month: 12, day: 19, hour: 16, minute: 39, second: 57, time_zone: &quot;Etc/UTC&quot;, zone_abbr: &quot;UTC&quot;, std_offset: 0, utc_offset: 0, microsecond: {123000, 3}}} iex&gt; rfc3339_utc(&quot;1996-12-19T16:39:57,123Z&quot;) {:ok, %DateTime{year: 1996, month: 12, day: 19, hour: 16, minute: 39, second: 57, time_zone: &quot;Etc/UTC&quot;, zone_abbr: &quot;UTC&quot;, std_offset: 0, utc_offset: 0, microsecond: {123000, 3}}} iex&gt; rfc3339_utc(&quot;1996-12-19T16:39:57-08:00&quot;) {:ok, %DateTime{year: 1996, month: 12, day: 20, hour: 0, minute: 39, second: 57, time_zone: &quot;Etc/UTC&quot;, zone_abbr: &quot;UTC&quot;, std_offset: 0, utc_offset: 0}} # No seperation chars between numbers. Not RFC3339, but we still parse it. iex&gt; rfc3339_utc(&quot;19961219T163957-08:00&quot;) {:ok, %DateTime{year: 1996, month: 12, day: 20, hour: 0, minute: 39, second: 57, time_zone: &quot;Etc/UTC&quot;, zone_abbr: &quot;UTC&quot;, std_offset: 0, utc_offset: 0}} # Offset does not have colon (-0800). That makes it ISO8601, but not RFC3339. We still parse it. iex&gt; rfc3339_utc(&quot;1996-12-19T16:39:57-0800&quot;) {:ok, %DateTime{year: 1996, month: 12, day: 20, hour: 0, minute: 39, second: 57, time_zone: &quot;Etc/UTC&quot;, zone_abbr: &quot;UTC&quot;, std_offset: 0, utc_offset: 0}}"},{"ref":"Calendar.DateTime.Parse.html#rfc822_utc/2","title":"Calendar.DateTime.Parse.rfc822_utc/2","type":"function","doc":"Parses an RFC 822 datetime string and shifts it to UTC. Takes an RFC 822 string and year_guessing_base. The year_guessing_base argument is used in case of a two digit year which is allowed in RFC 822. The function tries to guess possible four digit versions of the year and chooses the one closest to year_guessing_base. It defaults to 2015. Examples # 2 digit year iex&gt; &quot;5 Jul 15 20:26:13 PST&quot; |&gt; rfc822_utc {:ok, %DateTime{zone_abbr: &quot;UTC&quot;, day: 6, hour: 4, minute: 26, month: 7, second: 13, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, microsecond: {0, 0}, utc_offset: 0, year: 2015}} # 82 as year iex&gt; &quot;5 Jul 82 20:26:13 PST&quot; |&gt; rfc822_utc {:ok, %DateTime{zone_abbr: &quot;UTC&quot;, day: 6, hour: 4, minute: 26, month: 7, second: 13, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, microsecond: {0, 0}, utc_offset: 0, year: 1982}} # 1982 as year iex&gt; &quot;5 Jul 82 20:26:13 PST&quot; |&gt; rfc822_utc {:ok, %DateTime{zone_abbr: &quot;UTC&quot;, day: 6, hour: 4, minute: 26, month: 7, second: 13, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, microsecond: {0, 0}, utc_offset: 0, year: 1982}} # 2 digit year and we use 2099 as the base guessing year # which means that 15 should be interpreted as 2115 no 2015 iex&gt; &quot;5 Jul 15 20:26:13 PST&quot; |&gt; rfc822_utc(2099) {:ok, %DateTime{zone_abbr: &quot;UTC&quot;, day: 6, hour: 4, minute: 26, month: 7, second: 13, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, microsecond: {0, 0}, utc_offset: 0, year: 2115}}"},{"ref":"Calendar.DateTime.Parse.html#unix!/1","title":"Calendar.DateTime.Parse.unix!/1","type":"function","doc":"Takes unix time as an integer or float. Returns a DateTime struct. Examples iex&gt; unix!(1_000_000_000) %DateTime{zone_abbr: &quot;UTC&quot;, day: 9, microsecond: {0, 0}, hour: 1, minute: 46, month: 9, second: 40, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2001} iex&gt; unix!(&quot;1000000000&quot;) %DateTime{zone_abbr: &quot;UTC&quot;, day: 9, microsecond: {0, 0}, hour: 1, minute: 46, month: 9, second: 40, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2001} iex&gt; unix!(&quot;1000000000.010&quot;) %DateTime{zone_abbr: &quot;UTC&quot;, day: 9, microsecond: {10_000, 3}, hour: 1, minute: 46, month: 9, second: 40, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2001} iex&gt; unix!(1_000_000_000.9876) %DateTime{zone_abbr: &quot;UTC&quot;, day: 9, microsecond: {987600, 6}, hour: 1, minute: 46, month: 9, second: 40, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2001} iex&gt; unix!(1_000_000_000.999999) %DateTime{zone_abbr: &quot;UTC&quot;, day: 9, microsecond: {999999, 6}, hour: 1, minute: 46, month: 9, second: 40, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2001}"},{"ref":"Calendar.DateTime.TzPeriod.html","title":"Calendar.DateTime.TzPeriod","type":"module","doc":"Deprecated: use the Tzdata module instead"},{"ref":"Calendar.DateTime.TzPeriod.html#from/1","title":"Calendar.DateTime.TzPeriod.from/1","type":"function","doc":"Takes a DateTime. Returns the beginning of the timezone period that timezone is in as another DateTime in a tuple tagged with :ok In case it is the first timezone period, the beginning will be &quot;the beginning of time&quot; so to speak. In that case {:unlimited, :min} will be returned. See also timezone_period_until. Examples iex&gt; Calendar.DateTime.from_erl!({{2000,1,1},{0,0,0}},&quot;Atlantic/Reykjavik&quot;) |&gt; from {:ok, %DateTime{zone_abbr: &quot;GMT&quot;, day: 7, hour: 2, microsecond: {0, 0}, minute: 0, month: 4, second: 0, std_offset: 0, time_zone: &quot;Atlantic/Reykjavik&quot;, utc_offset: 0, year: 1968}} iex&gt; Calendar.DateTime.from_erl!({{1800,1,1},{0,0,0}},&quot;Atlantic/Reykjavik&quot;) |&gt; from {:unlimited, :min}"},{"ref":"Calendar.DateTime.TzPeriod.html#next_from/1","title":"Calendar.DateTime.TzPeriod.next_from/1","type":"function","doc":"Takes a DateTime. Returns another DateTime with the beginning of the next timezone period. Or {:unlimited, :max} in case there are no planned changes to the time zone. See also from. Examples Iceland does not observe DST and has no plans to do so. The period that 2000 January 1st is in goes on &quot;forever&quot; and {:unlimited, :max} is returned. iex&gt; Calendar.DateTime.from_erl!({{2000,1,1},{0,0,0}},&quot;Atlantic/Reykjavik&quot;) |&gt; next_from {:unlimited, :max} The provided DateTime is in summer of 2000 in New York. The period is in DST. The returned DateTime is the first instance of winter time, where DST is no longer in place: iex&gt; Calendar.DateTime.from_erl!({{2000,6,1},{0,0,0}},&quot;America/New_York&quot;) |&gt; next_from {:ok, %DateTime{zone_abbr: &quot;EST&quot;, day: 29, hour: 1, microsecond: {0, 0}, minute: 0, month: 10, second: 0, std_offset: 0, time_zone: &quot;America/New_York&quot;, utc_offset: -18000, year: 2000}} The provided DateTime is in winter 2000. The returned DateTime is the first second of DST/summer time. iex&gt; Calendar.DateTime.from_erl!({{2000,1,1},{0,0,0}},&quot;Europe/Copenhagen&quot;) |&gt; next_from {:ok, %DateTime{zone_abbr: &quot;CEST&quot;, day: 26, hour: 3, microsecond: {0, 0}, minute: 0, month: 3, second: 0, std_offset: 3600, time_zone: &quot;Europe/Copenhagen&quot;, utc_offset: 3600, year: 2000}}"},{"ref":"Calendar.DateTime.TzPeriod.html#prev_from/1","title":"Calendar.DateTime.TzPeriod.prev_from/1","type":"function","doc":"Examples iex&gt; Calendar.DateTime.from_erl!({{2000,1,1},{0,0,0}},&quot;Europe/Copenhagen&quot;) |&gt; prev_from {:ok, %DateTime{zone_abbr: &quot;CEST&quot;, day: 28, hour: 3, microsecond: {0, 0}, minute: 0, month: 3, second: 0, std_offset: 3600, time_zone: &quot;Europe/Copenhagen&quot;, utc_offset: 3600, year: 1999}} iex&gt; Calendar.DateTime.from_erl!({{1800,1,1},{0,0,0}},&quot;Atlantic/Reykjavik&quot;) |&gt; prev_from {:error, :already_at_first}"},{"ref":"Calendar.DateTime.TzPeriod.html#stream_next_from/1","title":"Calendar.DateTime.TzPeriod.stream_next_from/1","type":"function","doc":"Takes a DateTime and returns a stream of next timezone period starts. Not including the &quot;from&quot; time of the current timezone period. Examples A DateTime in winter is provided. We take the first 4 elements from the stream. The first element is the first instance of the summer time period that follows the standard/winter time period the provided DateTime was in. The next is standard time. Then Daylight time and Standard time again. iex&gt; Calendar.DateTime.from_erl!({{2015,2,24},{13,0,0}}, &quot;America/New_York&quot;) |&gt; stream_next_from |&gt; Enum.take(4) [%DateTime{zone_abbr: &quot;EDT&quot;, day: 8, hour: 3, microsecond: {0, 0}, minute: 0, month: 3, second: 0, std_offset: 3600, time_zone: &quot;America/New_York&quot;, utc_offset: -18000, year: 2015}, %DateTime{zone_abbr: &quot;EST&quot;, day: 1, hour: 1, microsecond: {0, 0}, minute: 0, month: 11, second: 0, std_offset: 0, time_zone: &quot;America/New_York&quot;, utc_offset: -18000, year: 2015}, %DateTime{zone_abbr: &quot;EDT&quot;, day: 13, hour: 3, microsecond: {0, 0}, minute: 0, month: 3, second: 0, std_offset: 3600, time_zone: &quot;America/New_York&quot;, utc_offset: -18000, year: 2016}, %DateTime{zone_abbr: &quot;EST&quot;, day: 6, hour: 1, microsecond: {0, 0}, minute: 0, month: 11, second: 0, std_offset: 0, time_zone: &quot;America/New_York&quot;, utc_offset: -18000, year: 2016}]"},{"ref":"Calendar.DateTime.TzPeriod.html#stream_prev_from/1","title":"Calendar.DateTime.TzPeriod.stream_prev_from/1","type":"function","doc":"Takes a DateTime and returns a stream of previous &quot;from&quot; timezone period starts. Plus the &quot;from&quot; time of the current timezone period. Examples A DateTime in winter is provided. We take the first 4 elements from the stream. The first element is the beginning of the period for the DateTime provided. The next is the first instance of summer time aka. Eastern Daylight Time earlier that year. The next one is standard time before that which began in the previous year. iex&gt; Calendar.DateTime.from_erl!({{2015,2,24},{13,0,0}}, &quot;America/New_York&quot;) |&gt; stream_prev_from |&gt; Enum.take(4) [%DateTime{zone_abbr: &quot;EST&quot;, day: 2, hour: 1, microsecond: {0, 0}, minute: 0, month: 11, second: 0, std_offset: 0, time_zone: &quot;America/New_York&quot;, utc_offset: -18000, year: 2014}, %DateTime{zone_abbr: &quot;EDT&quot;, day: 9, hour: 3, microsecond: {0, 0}, minute: 0, month: 3, second: 0, std_offset: 3600, time_zone: &quot;America/New_York&quot;, utc_offset: -18000, year: 2014}, %DateTime{zone_abbr: &quot;EST&quot;, day: 3, hour: 1, microsecond: {0, 0}, minute: 0, month: 11, second: 0, std_offset: 0, time_zone: &quot;America/New_York&quot;, utc_offset: -18000, year: 2013}, %DateTime{zone_abbr: &quot;EDT&quot;, day: 10, hour: 3, microsecond: {0, 0}, minute: 0, month: 3, second: 0, std_offset: 3600, time_zone: &quot;America/New_York&quot;, utc_offset: -18000, year: 2013}]"},{"ref":"Calendar.DefaultTranslations.html","title":"Calendar.DefaultTranslations","type":"module","doc":""},{"ref":"Calendar.DefaultTranslations.html#date_format/1","title":"Calendar.DefaultTranslations.date_format/1","type":"function","doc":""},{"ref":"Calendar.DefaultTranslations.html#date_time_format/1","title":"Calendar.DefaultTranslations.date_time_format/1","type":"function","doc":""},{"ref":"Calendar.DefaultTranslations.html#month_names/1","title":"Calendar.DefaultTranslations.month_names/1","type":"function","doc":""},{"ref":"Calendar.DefaultTranslations.html#month_names_abbr/1","title":"Calendar.DefaultTranslations.month_names_abbr/1","type":"function","doc":""},{"ref":"Calendar.DefaultTranslations.html#time_format/1","title":"Calendar.DefaultTranslations.time_format/1","type":"function","doc":""},{"ref":"Calendar.DefaultTranslations.html#weekday_names/1","title":"Calendar.DefaultTranslations.weekday_names/1","type":"function","doc":""},{"ref":"Calendar.DefaultTranslations.html#weekday_names_abbr/1","title":"Calendar.DefaultTranslations.weekday_names_abbr/1","type":"function","doc":""},{"ref":"Calendar.NaiveDateTime.html","title":"Calendar.NaiveDateTime","type":"module","doc":"NaiveDateTime can represents a &quot;naive time&quot;. That is a point in time without a specified time zone."},{"ref":"Calendar.NaiveDateTime.html#add/2","title":"Calendar.NaiveDateTime.add/2","type":"function","doc":"Takes a NaiveDateTime and an integer. Returns the naive_date_time advanced by the number of seconds found in the seconds argument. If seconds is negative, the time is moved back. Examples # Advance 2 seconds iex&gt; from_erl!({{2014,10,2},{0,29,10}}, 123456) |&gt; add(2) {:ok, %NaiveDateTime{day: 2, hour: 0, minute: 29, month: 10, second: 12, microsecond: {123456, 6}, year: 2014}}"},{"ref":"Calendar.NaiveDateTime.html#add!/2","title":"Calendar.NaiveDateTime.add!/2","type":"function","doc":"Like add without exclamation points. Instead of returning a tuple with :ok and the result, the result is returned untagged. Will raise an error in case no correct result can be found based on the arguments. Examples # Advance 2 seconds iex&gt; from_erl!({{2014,10,2},{0,29,10}}, 123456) |&gt; add!(2) %NaiveDateTime{day: 2, hour: 0, minute: 29, month: 10, second: 12, microsecond: {123456, 6}, year: 2014}"},{"ref":"Calendar.NaiveDateTime.html#advance/2","title":"Calendar.NaiveDateTime.advance/2","type":"function","doc":"Deprecated version of add/2"},{"ref":"Calendar.NaiveDateTime.html#advance!/2","title":"Calendar.NaiveDateTime.advance!/2","type":"function","doc":"Deprecated version of add!/2"},{"ref":"Calendar.NaiveDateTime.html#after?/2","title":"Calendar.NaiveDateTime.after?/2","type":"function","doc":"Takes a two NaiveDateTimes and returns true if the first one is greater than the second. Otherwise false. Greater than means that it is later then the second datetime. Examples iex&gt; {{2014,1,1}, {10,10,10}} |&gt; after?({{1999, 1, 1}, {11, 11, 11}}) true iex&gt; {{2014,1,1}, {10,10,10}} |&gt; after?({{2020, 1, 1}, {11, 11, 11}}) false iex&gt; {{2014,1,1}, {10,10,10}} |&gt; after?({{2014, 1, 1}, {10, 10, 10}}) false"},{"ref":"Calendar.NaiveDateTime.html#before?/2","title":"Calendar.NaiveDateTime.before?/2","type":"function","doc":"Takes a two NaiveDateTimes and returns true if the first one is less than the second. Otherwise false. Less than means that it is earlier then the second datetime. Examples iex&gt; {{2014,1,1}, {10,10,10}} |&gt; before?({{1999, 1, 1}, {11, 11, 11}}) false iex&gt; {{2014,1,1}, {10,10,10}} |&gt; before?({{2020, 1, 1}, {11, 11, 11}}) true iex&gt; {{2014,1,1}, {10,10,10}} |&gt; before?({{2014, 1, 1}, {10, 10, 10}}) false"},{"ref":"Calendar.NaiveDateTime.html#diff/2","title":"Calendar.NaiveDateTime.diff/2","type":"function","doc":"The difference between two naive datetimes. In seconds and microseconds. Returns tuple with {:ok, seconds, microseconds, :before or :after or :same_time} If the first argument is later (e.g. greater) the second, the result will be positive. In case of a negative result the second element (seconds) will be negative. This is always the case if both of the arguments have the microseconds as nil or 0. But if the difference is less than a second and the result is negative, then the microseconds will be negative. Examples # The first NaiveDateTime is 40 seconds after the second NaiveDateTime iex&gt; diff({{2014,10,2},{0,29,50}}, {{2014,10,2},{0,29,10}}) {:ok, 40, 0, :after} # The first NaiveDateTime is 40 seconds before the second NaiveDateTime iex&gt; diff({{2014,10,2},{0,29,10}}, {{2014,10,2},{0,29,50}}) {:ok, -40, 0, :before} iex&gt; diff(from_erl!({{2014,10,2},{0,29,10}},{999999, 6}), from_erl!({{2014,10,2},{0,29,50}})) {:ok, -39, 1, :before} iex&gt; diff(from_erl!({{2014,10,2},{0,29,10}},{999999, 6}), from_erl!({{2014,10,2},{0,29,11}})) {:ok, 0, -1, :before} iex&gt; diff(from_erl!({{2014,10,2},{0,29,11}}), from_erl!({{2014,10,2},{0,29,10}},{999999, 6})) {:ok, 0, 1, :after} iex&gt; diff(from_erl!({{2014,10,2},{0,29,11}}), from_erl!({{2014,10,2},{0,29,11}})) {:ok, 0, 0, :same_time}"},{"ref":"Calendar.NaiveDateTime.html#from_date_and_time/2","title":"Calendar.NaiveDateTime.from_date_and_time/2","type":"function","doc":"Create new NaiveDateTime struct based on a date and a time. Examples iex&gt; from_date_and_time({2016, 1, 8}, {14, 10, 55}) {:ok, %NaiveDateTime{day: 8, microsecond: {0, 0}, hour: 14, minute: 10, month: 1, second: 55, year: 2016}} iex&gt; from_date_and_time(Calendar.Date.Parse.iso8601!(&quot;2016-01-08&quot;), {14, 10, 55}) {:ok, %NaiveDateTime{day: 8, microsecond: {0, 0}, hour: 14, minute: 10, month: 1, second: 55, year: 2016}}"},{"ref":"Calendar.NaiveDateTime.html#from_date_and_time!/2","title":"Calendar.NaiveDateTime.from_date_and_time!/2","type":"function","doc":"Like from_date_and_time/2 but returns the result untagged. Raises in case of an error. Example iex&gt; from_date_and_time!({2016, 1, 8}, {14, 10, 55}) %NaiveDateTime{day: 8, microsecond: {0, 0}, hour: 14, minute: 10, month: 1, second: 55, year: 2016}"},{"ref":"Calendar.NaiveDateTime.html#from_erl/2","title":"Calendar.NaiveDateTime.from_erl/2","type":"function","doc":"Takes an Erlang-style date-time tuple. If the datetime is valid it returns a tuple with a tag and a naive DateTime. Naive in this context means that it does not have any timezone data. Examples iex&gt;from_erl({{2014, 9, 26}, {17, 10, 20}}) {:ok, %NaiveDateTime{day: 26, hour: 17, minute: 10, month: 9, second: 20, year: 2014} } iex&gt;from_erl({{2014, 9, 26}, {17, 10, 20}}, 321321) {:ok, %NaiveDateTime{day: 26, hour: 17, minute: 10, month: 9, second: 20, year: 2014, microsecond: {321321, 6}} } # Invalid date iex&gt;from_erl({{2014, 99, 99}, {17, 10, 20}}) {:error, :invalid_datetime} # Invalid time iex&gt;from_erl({{2014, 9, 26}, {17, 70, 20}}) {:error, :invalid_datetime}"},{"ref":"Calendar.NaiveDateTime.html#from_erl!/2","title":"Calendar.NaiveDateTime.from_erl!/2","type":"function","doc":"Like from_erl/1 without &quot;!&quot;, but returns the result directly without a tag. Will raise if date is invalid. Only use this if you are sure the date is valid. Examples iex&gt; from_erl!({{2014, 9, 26}, {17, 10, 20}}) %NaiveDateTime{day: 26, hour: 17, minute: 10, month: 9, second: 20, year: 2014} iex from_erl!({{2014, 99, 99}, {17, 10, 20}}) # this will throw a MatchError"},{"ref":"Calendar.NaiveDateTime.html#gregorian_seconds/1","title":"Calendar.NaiveDateTime.gregorian_seconds/1","type":"function","doc":"Takes a NaiveDateTime and returns an integer of gregorian seconds starting with year 0. This is done via the Erlang calendar module. Examples iex&gt; from_erl!({{2014,9,26},{17,10,20}}) |&gt; gregorian_seconds 63578970620"},{"ref":"Calendar.NaiveDateTime.html#same_time?/2","title":"Calendar.NaiveDateTime.same_time?/2","type":"function","doc":"Takes a two NaiveDateTimes and returns true if the first is equal to the second one. In this context equal means that they happen at the same time. Examples iex&gt; {{2014,1,1}, {10,10,10}} |&gt; same_time?({{1999, 1, 1}, {11, 11, 11}}) false iex&gt; {{2014,1,1}, {10,10,10}} |&gt; same_time?({{2020, 1, 1}, {11, 11, 11}}) false iex&gt; {{2014,1,1}, {10,10,10}} |&gt; same_time?({{2014, 1, 1}, {10, 10, 10}}) true"},{"ref":"Calendar.NaiveDateTime.html#subtract/2","title":"Calendar.NaiveDateTime.subtract/2","type":"function","doc":""},{"ref":"Calendar.NaiveDateTime.html#subtract!/2","title":"Calendar.NaiveDateTime.subtract!/2","type":"function","doc":""},{"ref":"Calendar.NaiveDateTime.html#to_date/1","title":"Calendar.NaiveDateTime.to_date/1","type":"function","doc":"Takes a NaiveDateTime struct and returns a Date struct representing the date part of the provided NaiveDateTime. iex&gt; from_erl!({{2014,10,15},{2,37,22}}) |&gt; Calendar.NaiveDateTime.to_date %Date{day: 15, month: 10, year: 2014}"},{"ref":"Calendar.NaiveDateTime.html#to_date_time/2","title":"Calendar.NaiveDateTime.to_date_time/2","type":"function","doc":"For turning NaiveDateTime structs to into a DateTime. Takes a NaiveDateTime and a timezone name. If timezone is valid, returns a tuple with an :ok and DateTime. iex&gt; from_erl!({{2014,10,15},{2,37,22}}) |&gt; Calendar.NaiveDateTime.to_date_time(&quot;UTC&quot;) {:ok, %DateTime{zone_abbr: &quot;UTC&quot;, day: 15, microsecond: {0, 0}, hour: 2, minute: 37, month: 10, second: 22, std_offset: 0, time_zone: &quot;UTC&quot;, utc_offset: 0, year: 2014}}"},{"ref":"Calendar.NaiveDateTime.html#to_date_time_utc/1","title":"Calendar.NaiveDateTime.to_date_time_utc/1","type":"function","doc":"Promote to DateTime with UTC time zone. Should only be used if you are sure that the provided argument is in UTC. Takes a NaiveDateTime. Returns a DateTime. iex&gt; from_erl!({{2014,10,15},{2,37,22}}) |&gt; Calendar.NaiveDateTime.to_date_time_utc %DateTime{zone_abbr: &quot;UTC&quot;, day: 15, microsecond: {0, 0}, hour: 2, minute: 37, month: 10, second: 22, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2014}"},{"ref":"Calendar.NaiveDateTime.html#to_erl/1","title":"Calendar.NaiveDateTime.to_erl/1","type":"function","doc":"Takes a NaiveDateTime struct and returns an erlang style datetime tuple. Examples iex&gt; from_erl!({{2014, 10, 15}, {2, 37, 22}}) |&gt; to_erl {{2014, 10, 15}, {2, 37, 22}}"},{"ref":"Calendar.NaiveDateTime.html#to_micro_erl/1","title":"Calendar.NaiveDateTime.to_micro_erl/1","type":"function","doc":"Takes a NaiveDateTime struct and returns an Ecto style datetime tuple. This is like an erlang style tuple, but with microseconds added as an additional element in the time part of the tuple. If the datetime has its microsecond field set to nil, 0 will be used for microsecond. Examples iex&gt; from_erl!({{2014,10,15},{2,37,22}}, {999999, 6}) |&gt; Calendar.NaiveDateTime.to_micro_erl {{2014, 10, 15}, {2, 37, 22, 999999}} iex&gt; from_erl!({{2014,10,15},{2,37,22}}, {0, 0}) |&gt; Calendar.NaiveDateTime.to_micro_erl {{2014, 10, 15}, {2, 37, 22, 0}}"},{"ref":"Calendar.NaiveDateTime.html#to_time/1","title":"Calendar.NaiveDateTime.to_time/1","type":"function","doc":"Takes a NaiveDateTime struct and returns a Time struct representing the time part of the provided NaiveDateTime. iex&gt; from_erl!({{2014,10,15},{2,37,22}}) |&gt; Calendar.NaiveDateTime.to_time %Time{microsecond: {0, 0}, hour: 2, minute: 37, second: 22}"},{"ref":"Calendar.NaiveDateTime.html#with_offset_to_datetime_utc/2","title":"Calendar.NaiveDateTime.with_offset_to_datetime_utc/2","type":"function","doc":"If you have a naive datetime and you know the offset, promote it to a UTC DateTime. Examples # A naive datetime at 2:37:22 with a 3600 second offset will return # a UTC DateTime with the same date, but at 1:37:22 iex&gt; with_offset_to_datetime_utc {{2014,10,15},{2,37,22}}, 3600 {:ok, %DateTime{zone_abbr: &quot;UTC&quot;, day: 15, microsecond: {0, 0}, hour: 1, minute: 37, month: 10, second: 22, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2014} } iex&gt; with_offset_to_datetime_utc{{2014,10,15},{2,37,22}}, 999_999_999_999_999_999_999_999_999 {:error, nil}"},{"ref":"Calendar.NaiveDateTime.Format.html","title":"Calendar.NaiveDateTime.Format","type":"module","doc":""},{"ref":"Calendar.NaiveDateTime.Format.html#asctime/1","title":"Calendar.NaiveDateTime.Format.asctime/1","type":"function","doc":"Format a naive datetime as &quot;c time&quot; Examples iex&gt; {{2015, 3, 3}, {7, 5, 3}} |&gt; asctime &quot;Tue Mar 3 07:05:03 2015&quot;"},{"ref":"Calendar.NaiveDateTime.Format.html#iso8601/1","title":"Calendar.NaiveDateTime.Format.iso8601/1","type":"function","doc":"Format a naive datetime as ISO 8601 in extended format. Examples iex&gt; {{2015, 4, 3}, {7, 5, 3}} |&gt; iso8601 &quot;2015-04-03T07:05:03&quot;"},{"ref":"Calendar.NaiveDateTime.Format.html#iso8601_basic/1","title":"Calendar.NaiveDateTime.Format.iso8601_basic/1","type":"function","doc":"Format a naive datetime as ISO 8601 in basic format. Examples iex&gt; {{2015, 4, 3}, {7, 5, 3}} |&gt; iso8601_basic &quot;20150403T070503&quot;"},{"ref":"Calendar.NaiveDateTime.Interval.html","title":"Calendar.NaiveDateTime.Interval","type":"module","doc":"A NaiveDateTime.Interval consists of a start and an end NaiveDateTime."},{"ref":"Calendar.NaiveDateTime.Interval.html#iso8601/1","title":"Calendar.NaiveDateTime.Interval.iso8601/1","type":"function","doc":"Formats interval in ISO 8601 extended format. Example: # With a `NaiveDateTime.Interval` iex&gt; %Calendar.NaiveDateTime.Interval{from: {{2016, 2, 27}, {10, 0, 0}} |&gt; Calendar.NaiveDateTime.from_erl!, to: {{2016, 3, 1}, {11, 0, 0}} |&gt; Calendar.NaiveDateTime.from_erl!} |&gt; Calendar.NaiveDateTime.Interval.iso8601 &quot;2016-02-27T10:00:00/2016-03-01T11:00:00&quot; # Also works with a `DateTime.Interval` iex&gt; %Calendar.DateTime.Interval{from: {{2016, 2, 27}, {10, 0, 0}} |&gt; Calendar.DateTime.from_erl!(&quot;Etc/UTC&quot;), to: {{2016, 3, 1}, {11, 0, 0}} |&gt; Calendar.DateTime.from_erl!(&quot;Etc/UTC&quot;)} |&gt; Calendar.NaiveDateTime.Interval.iso8601 &quot;2016-02-27T10:00:00/2016-03-01T11:00:00&quot;"},{"ref":"Calendar.NaiveDateTime.Interval.html#iso8601_basic/1","title":"Calendar.NaiveDateTime.Interval.iso8601_basic/1","type":"function","doc":"Formats interval in ISO 8601 basic format. Example: iex&gt; %Calendar.NaiveDateTime.Interval{from: {{2016, 2, 27}, {10, 0, 0}}, to: {{2016, 3, 1}, {11, 0, 0}}} |&gt; Calendar.NaiveDateTime.Interval.iso8601_basic &quot;20160227T100000/20160301T110000&quot; # Also works with a [`Calendar.DateTime.Interval`](Calendar.DateTime.Interval.html) iex&gt; %Calendar.DateTime.Interval{from: {{2016, 2, 27}, {10, 0, 0}} |&gt; Calendar.DateTime.from_erl!(&quot;Etc/UTC&quot;), to: {{2016, 3, 1}, {11, 0, 0}} |&gt; Calendar.DateTime.from_erl!(&quot;Etc/UTC&quot;)} |&gt; Calendar.NaiveDateTime.Interval.iso8601_basic &quot;20160227T100000/20160301T110000&quot;"},{"ref":"Calendar.NaiveDateTime.Interval.html#t:t/0","title":"Calendar.NaiveDateTime.Interval.t/0","type":"type","doc":""},{"ref":"Calendar.NaiveDateTime.Parse.html","title":"Calendar.NaiveDateTime.Parse","type":"module","doc":""},{"ref":"Calendar.NaiveDateTime.Parse.html#asctime/1","title":"Calendar.NaiveDateTime.Parse.asctime/1","type":"function","doc":"Parses a &quot;C time&quot; string. Examples iex&gt; Calendar.NaiveDateTime.Parse.asctime(&quot;Wed Apr 9 07:53:03 2003&quot;) {:ok, %NaiveDateTime{year: 2003, month: 4, day: 9, hour: 7, minute: 53, second: 3, microsecond: {0, 0}}} iex&gt; asctime(&quot;Thu, Apr 10 07:53:03 2003&quot;) {:ok, %NaiveDateTime{year: 2003, month: 4, day: 10, hour: 7, minute: 53, second: 3, microsecond: {0, 0}}}"},{"ref":"Calendar.NaiveDateTime.Parse.html#asctime!/1","title":"Calendar.NaiveDateTime.Parse.asctime!/1","type":"function","doc":"Like asctime/1, but returns the result without tagging it with :ok. Examples iex&gt; asctime!(&quot;Wed Apr 9 07:53:03 2003&quot;) %NaiveDateTime{year: 2003, month: 4, day: 9, hour: 7, minute: 53, second: 3, microsecond: {0, 0}} iex&gt; asctime!(&quot;Thu, Apr 10 07:53:03 2003&quot;) %NaiveDateTime{year: 2003, month: 4, day: 10, hour: 7, minute: 53, second: 3, microsecond: {0, 0}}"},{"ref":"Calendar.NaiveDateTime.Parse.html#asn1_generalized/1","title":"Calendar.NaiveDateTime.Parse.asn1_generalized/1","type":"function","doc":"Parse ASN.1 GeneralizedTime. Returns tuple with {:ok, [NaiveDateTime], UTC offset (optional)} Examples iex&gt; &quot;19851106210627.3&quot; |&gt; asn1_generalized {:ok, %NaiveDateTime{year: 1985, month: 11, day: 6, hour: 21, minute: 6, second: 27, microsecond: {300_000, 1}}, nil} iex&gt; &quot;19851106210627.3Z&quot; |&gt; asn1_generalized {:ok, %NaiveDateTime{year: 1985, month: 11, day: 6, hour: 21, minute: 6, second: 27, microsecond: {300_000, 1}}, 0} iex&gt; &quot;19851106210627.3-5000&quot; |&gt; asn1_generalized {:ok, %NaiveDateTime{year: 1985, month: 11, day: 6, hour: 21, minute: 6, second: 27, microsecond: {300_000, 1}}, -180000}"},{"ref":"Calendar.NaiveDateTime.Parse.html#iso8601/1","title":"Calendar.NaiveDateTime.Parse.iso8601/1","type":"function","doc":"Parses an ISO8601 datetime. Returns {:ok, NaiveDateTime struct, UTC offset in secods} In case there is no UTC offset, the third element of the tuple will be nil. Examples # With offset iex&gt; iso8601(&quot;1996-12-19T16:39:57-0200&quot;) {:ok, %NaiveDateTime{year: 1996, month: 12, day: 19, hour: 16, minute: 39, second: 57, microsecond: {0, 0}}, -7200} # Without offset iex&gt; iso8601(&quot;1996-12-19T16:39:57&quot;) {:ok, %NaiveDateTime{year: 1996, month: 12, day: 19, hour: 16, minute: 39, second: 57, microsecond: {0, 0}}, nil} # With fractional seconds iex&gt; iso8601(&quot;1996-12-19T16:39:57.123&quot;) {:ok, %NaiveDateTime{year: 1996, month: 12, day: 19, hour: 16, minute: 39, second: 57, microsecond: {123000, 3}}, nil} # With fractional seconds iex&gt; iso8601(&quot;1996-12-19T16:39:57,123&quot;) {:ok, %NaiveDateTime{year: 1996, month: 12, day: 19, hour: 16, minute: 39, second: 57, microsecond: {123000, 3}}, nil} # With Z denoting 0 offset iex&gt; iso8601(&quot;1996-12-19T16:39:57Z&quot;) {:ok, %NaiveDateTime{year: 1996, month: 12, day: 19, hour: 16, minute: 39, second: 57, microsecond: {0, 0}}, 0} # Invalid date iex&gt; iso8601(&quot;1996-13-19T16:39:57Z&quot;) {:error, :invalid_datetime, nil}"},{"ref":"Calendar.Strftime.html","title":"Calendar.Strftime","type":"module","doc":"Format different types of time representations as strings."},{"ref":"Calendar.Strftime.html#strftime/3","title":"Calendar.Strftime.strftime/3","type":"function","doc":"Generate a string from a DateTime, NaiveDateTime, Time or Date formatted by a format string. Similar to strftime known from Unix systems. Examples iex&gt; {{2014,9,6},{17,10,20}} |&gt; Calendar.NaiveDateTime.from_erl! |&gt; strftime(&quot;%A %Y-%m-%e %H:%M:%S&quot;) {:ok, &quot;Saturday 2014-09- 6 17:10:20&quot;} # Passing erlang style naive date time tuple directly iex&gt; {{2014,9,6},{17,10,20}} |&gt; strftime(&quot;%A %Y-%m-%e %H:%M:%S&quot;) {:ok, &quot;Saturday 2014-09- 6 17:10:20&quot;} iex&gt; Calendar.DateTime.from_erl!({{2014,9,6},{17,10,20}},&quot;Etc/UTC&quot;) |&gt; strftime(&quot;%A %Y-%m-%e %H:%M:%S&quot;) {:ok, &quot;Saturday 2014-09- 6 17:10:20&quot;} iex&gt; Calendar.DateTime.from_erl!({{2014,9,6},{17,10,20}},&quot;Etc/UTC&quot;) |&gt; strftime(&quot;%a %d.%m.%y&quot;) {:ok, &quot;Sat 06.09.14&quot;} # Passing a Date struct iex&gt; Calendar.Date.from_erl!({2014,9,6}) |&gt; strftime(&quot;%a %d.%m.%y&quot;) {:ok, &quot;Sat 06.09.14&quot;} # Trying to use date conversion specs and passing a Time struct results in errors iex&gt; Calendar.Time.from_erl!({12, 30, 59}) |&gt; strftime(&quot;%a %d.%m.%y&quot;) {:error, :missing_data_for_conversion_spec} # Passing a Time and using just conversion specs suitable for time iex&gt; Calendar.Time.from_erl!({12, 30, 59}) |&gt; strftime(&quot;%r&quot;) {:ok, &quot;12:30:59 PM&quot;} # Tuples in erlang datetime format will work like NaiveDateTime structs iex&gt; {{2014,9,6},{17,10,20}} |&gt; strftime(&quot;%A %Y-%m-%e %H:%M:%S&quot;) {:ok, &quot;Saturday 2014-09- 6 17:10:20&quot;} conversion spec.DescriptionExamplereq. datereq. timereq. TZ %aAbbreviated name of dayMon✓ %AFull name of dayMonday✓ %bAbbreviated month nameJan✓ %h(Equivalent to %b)✓ %BFull month nameJanuary✓ %jDay of the year as a decimal number (001 to 366).002✓ %uDay of the week as a decimal number (1 through 7). Also see %w1 for Monday✓ %wDay of the week as a decimal number (0 through 6). Also see %u0 for Sunday✓ %VWeek number (ISO 8601). (01 through 53)02 for week 2✓ %GYear for ISO 8601 week number (see %V). Not the same as %Y!2015✓ %g2 digit version of %G. Iso week-year. (00 through 99)15 for 2015✓ %y2 digit version of %Y. (00 through 99)15 for 2015✓ %YThe year in four digits. (0001 through 9999)2015✓ %CCentury number as two digits. 21st century will be 20.20 for year 2015✓ %IHour as decimal number using 12 hour clock. (01-12)07 for 19:00✓ %lLike %I but with single digits preceded by a space.7 for 19:00✓ %Pam or pm for 12 hour clock. In lower case.pm for 19:00✓ %pAM or PM for 12 hour clock. In upper case.PM for 19:00✓ %rTime in 12 hour notation. Equivalent to %I:%M:%S %p.07:25:41 PM✓ %RTime in 24 hour notation excluding seconds. Equivalent of %H:%M.19:25✓ %TTime in 24 hour notation. Equivalent of %H:%M:%S.19:25:41✓ %FDate in ISO 8601 format. Equivalent of %Y-%m-%d.2015-02-05✓ %xDate in in format for provided language05/02/2015✓ %cDate and time in format for provided languageWed Jan 13 11:34:10 2016✓✓ %vVMS date. Equivalent of %e-%b-%Y.5-Feb-2015✓ %mMonth as decimal number (01-12).01 for January✓ %eDay of the month as decimal number. Leading space if 1-digit.5 for 2015-02-05✓ %dDay of the month as decimal number. Leading zero. (01-31).05 for 2015-02-05✓ %HHour as decimal number using 24 hour clock (00-23).08 for 08:25✓ %kLike %H, but with leading space instead of leading zero.8 for 08:25✓ %MMinute as decimal number (00-59).04 for 19:04✓ %SSeconds as decimal number (00-60).02 for 19:04:02✓ %zHour and minute timezone offset from UTC.-0200✓✓✓ %ZTime zone abbreviation. Sometimes depends on DST.UYST✓✓✓ The ticks in the table above tells you what input is needed for the conversion spec. The table below shows which kinds of input you can use depending on which boxes are ticked: Which boxes are tickedCompatible input for conversion spec. dateDate, DateTime, NaiveDateTime, datetime tuple, date tuple timeTime, DateTime, NaiveDateTime, datetime tuple, time tuple date and timeDateTime, NaiveDateTime, datetime tuple date and time and TZDateTime"},{"ref":"Calendar.Strftime.html#strftime!/3","title":"Calendar.Strftime.strftime!/3","type":"function","doc":"Like strftime without the exclamation point, but returns the result without tagging it with :ok. Raises in case of errors. Examples # Passing NaiveDateTime struct iex&gt; {{2014,9,6},{17,10,20}} |&gt; Calendar.NaiveDateTime.from_erl! |&gt; strftime!(&quot;%A %Y-%m-%e %H:%M:%S&quot;) &quot;Saturday 2014-09- 6 17:10:20&quot; # Passing naive date time tuple iex&gt; {{2014,9,6},{17,10,20}} |&gt; strftime!(&quot;%A %Y-%m-%e %H:%M:%S&quot;) &quot;Saturday 2014-09- 6 17:10:20&quot; # Passing Date struct iex&gt; {2014,9,6} |&gt; Calendar.Date.from_erl! |&gt; strftime!(&quot;%A %Y-%m-%e&quot;) &quot;Saturday 2014-09- 6&quot; # Passing Time struct iex&gt; {17,10,20} |&gt; Calendar.Time.from_erl! |&gt; strftime!(&quot;%H:%M:%S&quot;) &quot;17:10:20&quot;"},{"ref":"Calendar.Time.html","title":"Calendar.Time","type":"module","doc":"The Time module provides a struct to represent a simple time without specifying a date, nor a time zone."},{"ref":"Calendar.Time.html#am?/1","title":"Calendar.Time.am?/1","type":"function","doc":"Returns true if provided time is AM in the twelve hour clock system. Otherwise false. Examples iex&gt; {8, 10, 23} |&gt; Calendar.Time.am? true iex&gt; {20, 10, 23} |&gt; Calendar.Time.am? false"},{"ref":"Calendar.Time.html#diff/2","title":"Calendar.Time.diff/2","type":"function","doc":"Difference in seconds between two times. Takes two Time structs: first_time and second_time. Subtracts second_time from first_time. iex&gt; from_erl!({0, 0, 30}) |&gt; diff(from_erl!({0, 0, 10})) 20 iex&gt; from_erl!({0, 0, 10}) |&gt; diff(from_erl!({0, 0, 30})) -20"},{"ref":"Calendar.Time.html#from_erl/2","title":"Calendar.Time.from_erl/2","type":"function","doc":"Create a Time struct using an erlang style tuple and optionally a microsecond second. Microsecond can either be a tuple of microsecond and precision. Or an integer with just the microsecond. iex&gt; from_erl({20,14,15}) {:ok, %Time{microsecond: {0, 0}, hour: 20, minute: 14, second: 15}} iex&gt; from_erl({20,14,15}, 123456) {:ok, %Time{microsecond: {123456, 6}, hour: 20, minute: 14, second: 15}} iex&gt; from_erl({20,14,15}, {123456, 6}) {:ok, %Time{microsecond: {123456, 6}, hour: 20, minute: 14, second: 15}} iex&gt; from_erl({24,14,15}) {:error, :invalid_time} iex&gt; from_erl({-1,0,0}) {:error, :invalid_time} iex&gt; from_erl({20,14,15}, {1_000_000, 6}) {:error, :invalid_time}"},{"ref":"Calendar.Time.html#from_erl!/2","title":"Calendar.Time.from_erl!/2","type":"function","doc":"Like from_erl, but will raise if the time is not valid. iex&gt; from_erl!({20,14,15}) %Time{microsecond: {0, 0}, hour: 20, minute: 14, second: 15} iex&gt; from_erl!({20,14,15}, {123456, 6}) %Time{microsecond: {123456, 6}, hour: 20, minute: 14, second: 15}"},{"ref":"Calendar.Time.html#from_second_in_day/1","title":"Calendar.Time.from_second_in_day/1","type":"function","doc":"Create a Time struct from an integer being the number of the second of the day. 00:00:00 being second 0 and 23:59:59 being number 86399 Examples iex&gt; 0 |&gt; from_second_in_day %Time{hour: 0, minute: 0, second: 0, microsecond: {0, 0}} iex&gt; 43200 |&gt; from_second_in_day %Time{hour: 12, minute: 0, second: 0, microsecond: {0, 0}} iex&gt; 86399 |&gt; from_second_in_day %Time{hour: 23, minute: 59, second: 59, microsecond: {0, 0}}"},{"ref":"Calendar.Time.html#next_second/1","title":"Calendar.Time.next_second/1","type":"function","doc":"Takes a time and returns a new time with the next second. If the provided time is 23:59:59 it returns a Time for 00:00:00. Examples iex&gt; {12, 0, 0} |&gt; next_second %Time{hour: 12, minute: 0, second: 1, microsecond: {0, 0}} # Preserves microseconds iex&gt; {12, 0, 0, 123456} |&gt; next_second %Time{hour: 12, minute: 0, second: 1, microsecond: {123456, 6}} # At the end of the day it goes to 00:00:00 iex&gt; {23, 59, 59} |&gt; next_second %Time{hour: 0, minute: 0, second: 0, microsecond: {0, 0}} iex&gt; {23, 59, 59, 300000} |&gt; next_second %Time{hour: 0, minute: 0, second: 0, microsecond: {300000, 6}}"},{"ref":"Calendar.Time.html#pm?/1","title":"Calendar.Time.pm?/1","type":"function","doc":"Returns true if provided time is AM in the twelve hour clock system. Otherwise false. Examples iex&gt; {8, 10, 23} |&gt; Calendar.Time.pm? false iex&gt; {20, 10, 23} |&gt; Calendar.Time.pm? true"},{"ref":"Calendar.Time.html#prev_second/1","title":"Calendar.Time.prev_second/1","type":"function","doc":"Takes a time and returns a new time with the previous second. If the provided time is 00:00:00 it returns a Time for 23:59:59. Examples iex&gt; {12, 0, 0} |&gt; prev_second %Time{hour: 11, minute: 59, second: 59, microsecond: {0, 0}} # Preserves microseconds iex&gt; {12, 0, 0, 123456} |&gt; prev_second %Time{hour: 11, minute: 59, second: 59, microsecond: {123456, 6}} # At the beginning of the day it goes to 23:59:59 iex&gt; {0, 0, 0} |&gt; prev_second %Time{hour: 23, minute: 59, second: 59, microsecond: {0, 0}} iex&gt; {0, 0, 0, 200_000} |&gt; prev_second %Time{hour: 23, minute: 59, second: 59, microsecond: {200_000, 6}}"},{"ref":"Calendar.Time.html#second_in_day/1","title":"Calendar.Time.second_in_day/1","type":"function","doc":"The number of the second in the day with 00:00:00 being second 1 and 23:59:59 being number 86400 Examples iex&gt; {0, 0, 0} |&gt; second_in_day 0 iex&gt; {23, 59, 59} |&gt; second_in_day 86399"},{"ref":"Calendar.Time.html#to_erl/1","title":"Calendar.Time.to_erl/1","type":"function","doc":"Takes a Time struct and returns an erlang style time tuple. Examples iex&gt; from_erl!({10, 20, 25}, {12345, 5}) |&gt; to_erl {10, 20, 25} iex&gt; {10, 20, 25} |&gt; to_erl {10, 20, 25}"},{"ref":"Calendar.Time.html#to_micro_erl/1","title":"Calendar.Time.to_micro_erl/1","type":"function","doc":"Takes a Time struct and returns an Ecto style time four-tuple with microseconds. If the Time struct has its usec field set to nil, 0 will be used for usec. Examples iex&gt; from_erl!({10, 20, 25}, 123456) |&gt; to_micro_erl {10, 20, 25, 123456} # If `usec` is nil, 0 is used instead as the last element in the tuple iex&gt; {10, 20, 25} |&gt; from_erl! |&gt; to_micro_erl {10, 20, 25, 0} iex&gt; {10, 20, 25} |&gt; to_micro_erl {10, 20, 25, 0}"},{"ref":"Calendar.Time.html#twelve_hour_time/1","title":"Calendar.Time.twelve_hour_time/1","type":"function","doc":"Converts a Time to the 12 hour format Returns a five element tuple with: {hours (1-12), minutes, seconds, microseconds, :am or :pm} Examples iex&gt; {13, 10, 23} |&gt; twelve_hour_time {1, 10, 23, {0, 0}, :pm} iex&gt; {0, 10, 23, 888888} |&gt; twelve_hour_time {12, 10, 23, {888888, 6}, :am}"},{"ref":"Calendar.Time.Format.html","title":"Calendar.Time.Format","type":"module","doc":""},{"ref":"Calendar.Time.Format.html#iso8601/1","title":"Calendar.Time.Format.iso8601/1","type":"function","doc":"Format a time as ISO 8601 extended format Examples iex&gt; Calendar.Time.from_erl!({20, 5, 18}) |&gt; Calendar.Time.Format.iso8601 &quot;20:05:18&quot;"},{"ref":"Calendar.Time.Format.html#iso_8601_basic/1","title":"Calendar.Time.Format.iso_8601_basic/1","type":"function","doc":"Format as ISO 8601 Basic Examples iex&gt; Calendar.Time.from_erl!({20, 10, 20}) |&gt; Calendar.Time.Format.iso_8601_basic &quot;201020&quot;"},{"ref":"Calendar.Time.Parse.html","title":"Calendar.Time.Parse","type":"module","doc":""},{"ref":"Calendar.Time.Parse.html#iso8601/1","title":"Calendar.Time.Parse.iso8601/1","type":"function","doc":"Parses ISO 8601 time strings. The function accepts both the extended and the basic format. Examples # Extended format iex&gt; iso8601(&quot;13:07:58&quot;) {:ok, %Time{hour: 13, minute: 7, second: 58}} # Basic format (the basic format does not have colons) iex&gt; iso8601(&quot;130758&quot;) {:ok, %Time{hour: 13, minute: 7, second: 58}} iex&gt; iso8601(&quot;25:65:00&quot;) {:error, :invalid_time}"},{"ref":"Calendar.Time.Parse.html#iso8601!/1","title":"Calendar.Time.Parse.iso8601!/1","type":"function","doc":"Parses ISO 8601 time strings. Like iso_8601/1, but returns the result untagged and raises in case of an error. Examples # Extended format iex&gt; iso8601!(&quot;13:07:58&quot;) %Time{hour: 13, minute: 7, second: 58}"},{"ref":"Calendar.TimeZoneData.html","title":"Calendar.TimeZoneData","type":"module","doc":"Deprecated: use the Tzdata library directly instead"},{"ref":"Calendar.TimeZoneData.html#canonical_zone?/1","title":"Calendar.TimeZoneData.canonical_zone?/1","type":"function","doc":"Takes the name of a zone. Returns true if zone exists and is canonical. Otherwise false. iex&gt; Calendar.TimeZoneData.canonical_zone? &quot;Europe/London&quot; true iex&gt; Calendar.TimeZoneData.canonical_zone? &quot;Europe/Jersey&quot; false Deprecated. Use Tzdata.canonical_zone? instead."},{"ref":"Calendar.TimeZoneData.html#canonical_zone_list/0","title":"Calendar.TimeZoneData.canonical_zone_list/0","type":"function","doc":"Like zone_list, but excludes aliases for zones. Deprecated. Use Tzdata.canonical_zone_list instead."},{"ref":"Calendar.TimeZoneData.html#leap_seconds/0","title":"Calendar.TimeZoneData.leap_seconds/0","type":"function","doc":"List of know leap seconds as DateTime structs Example: iex&gt; TimeZoneData.leap_seconds |&gt; Enum.take(2) [%DateTime{zone_abbr: &quot;UTC&quot;, day: 30, hour: 23, minute: 59, month: 6, second: 60, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, microsecond: {0, 0}, utc_offset: 0, year: 1972}, %DateTime{zone_abbr: &quot;UTC&quot;, day: 31, hour: 23, minute: 59, month: 12, second: 60, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, microsecond: {0, 0}, utc_offset: 0, year: 1972}] Deprecated. Use Tzdata.leap_seconds |&gt; Enum.map(&amp;Calendar.NaiveDateTime.from_erl!/1) |&gt; Enum.map(&amp;(DateTime.from_naive!(&amp;1, &quot;Etc/UTC&quot;))) instead."},{"ref":"Calendar.TimeZoneData.html#leap_seconds_erl/0","title":"Calendar.TimeZoneData.leap_seconds_erl/0","type":"function","doc":"List of known leap seconds in erlang tuple format in UTC. Example: iex&gt; TimeZoneData.leap_seconds_erl |&gt; Enum.take(2) [{{1972, 6, 30}, {23, 59, 60}}, {{1972, 12, 31}, {23, 59, 60}}] Deprecated. Use Tzdata.leap_seconds instead."},{"ref":"Calendar.TimeZoneData.html#links/0","title":"Calendar.TimeZoneData.links/0","type":"function","doc":"Returns a map of links. Also known as aliases. iex&gt; Calendar.TimeZoneData.links[&quot;Europe/Jersey&quot;] &quot;Europe/London&quot; Deprecated. Use Tzdata.links instead."},{"ref":"Calendar.TimeZoneData.html#periods/1","title":"Calendar.TimeZoneData.periods/1","type":"function","doc":"A list of pre-compiled periods for a given zone name. Deprecated. Use Tzdata.periods(zone_name) instead."},{"ref":"Calendar.TimeZoneData.html#periods_for_time/3","title":"Calendar.TimeZoneData.periods_for_time/3","type":"function","doc":""},{"ref":"Calendar.TimeZoneData.html#tzdata_version/0","title":"Calendar.TimeZoneData.tzdata_version/0","type":"function","doc":"Returns tzdata release version as a string. Example: Calendar.TimeZoneData.tzdata_version &quot;2014i&quot; Deprecated. Use Tzdata.tzdata_version instead."},{"ref":"Calendar.TimeZoneData.html#zone_alias?/1","title":"Calendar.TimeZoneData.zone_alias?/1","type":"function","doc":"Takes the name of a zone. Returns true if zone exists and is an alias. Otherwise false. iex&gt; Calendar.TimeZoneData.zone_alias? &quot;Europe/Jersey&quot; true iex&gt; Calendar.TimeZoneData.zone_alias? &quot;Europe/London&quot; false Deprecated. Use Tzdata.zone_alias? instead."},{"ref":"Calendar.TimeZoneData.html#zone_alias_list/0","title":"Calendar.TimeZoneData.zone_alias_list/0","type":"function","doc":"A list of aliases for zone names. For instance Europe/Jersey is an alias for Europe/London. Aliases are also known as linked zones. Deprecated. Use Tzdata.zone_alias_list instead."},{"ref":"Calendar.TimeZoneData.html#zone_exists?/1","title":"Calendar.TimeZoneData.zone_exists?/1","type":"function","doc":"Takes the name of a zone. Returns true zone exists. Otherwise false. iex&gt; Calendar.TimeZoneData.zone_exists? &quot;Pacific/Auckland&quot; true iex&gt; Calendar.TimeZoneData.zone_exists? &quot;America/Sao_Paulo&quot; true iex&gt; Calendar.TimeZoneData.zone_exists? &quot;Europe/Jersey&quot; true Deprecated. Use Tzdata.zone_exists? instead."},{"ref":"Calendar.TimeZoneData.html#zone_list/0","title":"Calendar.TimeZoneData.zone_list/0","type":"function","doc":"zone_list provides a list of all the zone names that can be used with DateTime. This includes aliases. Deprecated. Use Tzdata.zone_list instead."},{"ref":"Calendar.TimeZoneData.html#zone_lists_grouped/0","title":"Calendar.TimeZoneData.zone_lists_grouped/0","type":"function","doc":"Returns a map with keys being group names and the values lists of time zone names. The group names mirror the file names used by the tzinfo database. Deprecated. Use Tzdata.zone_lists_grouped instead."},{"ref":"readme.html","title":"Calendar","type":"extras","doc":"Calendar Calendar is a datetime library for Elixir. Providing explicit types for datetimes, dates and times. Full timezone support via its sister package tzdata. Safe parsing and formatting of standard formats (ISO, RFC, Unix, JS etc.) plus strftime formatting. Easy and safe interoperability with erlang style date, time, datetime tuples. Extendable through protocols. Related packages are available for i18n interoperability. Documentation is available on hexdocs."},{"ref":"readme.html#elixir-standard-library","title":"Calendar - Elixir standard library","type":"extras","doc":"Since the Calendar library was started, a lot of functionality previously only available in the Calendar library is now also available in the Elixir standard library. With Elixir 1.8 and later you can do time zone conversion in the DateTime module of the Elixir standard library provided you are using the tzdata library. Certain features like more advanced formatting are not yet available in the Elixir standard library. In these case this library is useful."},{"ref":"readme.html#getting-started","title":"Calendar - Getting started","type":"extras","doc":"Add Calendar as a dependency to an Elixir project by adding it to your mix.exs file: defp deps do [ {:calendar, &quot;~&gt; 0.18.0&quot;}, ] end Then run mix deps.get which will fetch Calendar via the hex package manager."},{"ref":"readme.html#types","title":"Calendar - Types","type":"extras","doc":"Since Elixir 1.3 the types used are now built into the Elixir standard library. Date - a simple date without time e.g. 2015-12-24 Time - a simple time without a date e.g. 14:30:00 or 15:21:12.532985 NaiveDateTime - datetimes without timezone information e.g. 2015-12-24 14:30:00 DateTime - datetimes where the proper timezone name is known e.g. 2015-12-24 14:30:00 in America/New_York or 2015-12-24 17:30:00 in Etc/UTC"},{"ref":"readme.html#string-formatting","title":"Calendar - String formatting","type":"extras","doc":"Calendar has polymorphic string formatting that does not get you into trouble by silently using fake data. If you need a well known format, such as RFC 3339 the DateTime.Format and NaiveDateTime.Format modules have functions for a lot of those. In case you want to do something custom or want to format simple Dates or Times, you can use the Strftime module. It uses formatting strings already known from the strftime &quot;standard&quot;. The strftime function takes all the struct types: Date, Time, DateTime, NaiveDateTime and datetime tuples. You just have to make sure that the conversion specs (the codes with the %-signs) are appropriate for whatever is input. # a Date struct works fine with these conversion specs (%a, %d, %m, %y) # because they just require a date Calendar.Date.from_erl!({2014,9,6}) |&gt; Calendar.Strftime.strftime &quot;%a %d.%m.%y&quot; {:ok, &quot;Sat 06.09.14&quot;} # A tuple like this is treated as a NaiveDateTime and also works because # it contains a date. {{2014,9,6}, {12, 13, 34}} |&gt; Calendar.Strftime.strftime &quot;%a %d.%m.%y&quot; {:ok, &quot;Sat 06.09.14&quot;} # Trying to use date conversion specs and passing a Time struct results in an # error because a Time struct does not have the year or any other of the # data necessary for the string &quot;%a %d.%m.%y&quot; Calendar.Time.from_erl!({12, 30, 59}) |&gt; Calendar.Strftime.strftime &quot;%a %d.%m.%y&quot; {:error, :missing_data_for_conversion_spec}"},{"ref":"readme.html#polymorphism-and-protocols","title":"Calendar - Polymorphism and protocols","type":"extras","doc":"The functions of each module are appropriate for that type. For instance the Date module has a function next_day! that returns a Date struct for the next day of a provided date. Any Calendar type that contains a date can be used as an argument. So in addition to Date, a DateTime or NaiveDateTime can be used. Also erlang-style tuples with a date or date-time can be used. Example: {2015, 12, 24} |&gt; Calendar.Date.next_day! ~D[2015-12-25] And using a NaiveDateTime containing the date 2015-12-24 would also return a Date struct for 2015-12-25: Calendar.NaiveDateTime.from_erl!({{2015, 12, 24}, {13, 45, 55}}) |&gt; Calendar.Date.next_day! ~D[2015-12-25] In the same fashion other tuples with at least the same amount of information can be used with other modules. E.g.NaiveDateTime, DateTime, Time structs can be used in the Time module because they all contain an hour, minute and second. DateTime structs and erlang style datetime tuples can be used in the NaiveDateTime module because they contain a date and a time. File.lstat!/2 is an example of a function that returns datetime tuples. A datetime tuple can be used in place of a NaiveDateTime, Date or Time. # Returns the mtime of the file mix.exs &gt; File.lstat!(&quot;mix.exs&quot;).mtime {{2015, 12, 31}, {14, 30, 26}} # Format this datetime using one of the NaiveDateTime fun File.lstat!(&quot;mix.exs&quot;).mtime |&gt; Calendar.NaiveDateTime.Format.asctime &quot;Thu Dec 31 14:30:26 2015&quot; # Using the tuple with the Date class, the date information is used &gt; File.lstat!(&quot;mix.exs&quot;).mtime |&gt; Calendar.Date.day_of_week_name &quot;Thursday&quot; # We know from the erlang documentation that lstat! by default returns UTC. # But the tuple does not contain this information. # So we can explicitly cast the tuple to be a DateTime in UTC. # And then pipe that to the DateTime.Format.unix function in order to get a UNIX timestamp &gt; File.lstat!(&quot;mix.exs&quot;).mtime |&gt; Calendar.NaiveDateTime.to_date_time_utc |&gt; Calendar.DateTime.Format.unix 1451572226 # String formatting &gt; File.lstat!(&quot;mix.exs&quot;).mtime |&gt; Calendar.Strftime.strftime!(&quot;%H:%M:%S&quot;) &quot;14:30:26&quot;"},{"ref":"readme.html#date-examples","title":"Calendar - Date examples","type":"extras","doc":"The Date module is used for handling dates. # You can create a new date with the from_erl! function: &gt; jan_first = {2015, 1, 1} |&gt; Calendar.Date.from_erl! ~D[2015-01-01] # Get a date that is 10000 days ahead of that one &gt; ten_k_days_later = jan_first |&gt; Calendar.Date.add!(10000) ~D[2042-05-19] # Is it friday? &gt; jan_first |&gt; Calendar.Date.friday? false # What day of the week is it? &gt; jan_first |&gt; Calendar.Date.day_of_week_name &quot;Thursday&quot; # Compare dates &gt; jan_first |&gt; Calendar.Date.before?({2015, 12, 24}) true # Get the difference in days between two dates. Using the Elixir 1.3 Date sigil. &gt; jan_first |&gt; Calendar.Date.diff(~D[2015-12-24]) -357 # Because of protocols, datetimes can also be provided as arguments, # but only the date will be used &gt; jan_first |&gt; Calendar.Date.diff({{2015, 12, 24}, {9, 10, 10}}) -357 # Use the DateTime module to get the time right now and # pipe it to the Date module to get the week number &gt; Calendar.DateTime.now_utc |&gt; Calendar.Date.week_number {2015, 28} # Pipe the week number tuple into another function to get a list # of the dates for that week &gt; Calendar.DateTime.now_utc |&gt; Calendar.Date.week_number |&gt; Calendar.Date.dates_for_week_number [~D[2016-06-13], ~D[2016-06-14], ~D[2016-06-15], ~D[2016-06-16], ~D[2016-06-17], ~D[2016-06-18], ~D[2016-06-19]]"},{"ref":"readme.html#naivedatetime","title":"Calendar - NaiveDateTime","type":"extras","doc":"Use NaiveDateTime modules when you have a date-time, but do not know the timezone. # An erlang style datetime tuple advanced 10 seconds {{1999, 12, 31}, {23, 59, 59}} |&gt; Calendar.NaiveDateTime.add!(10) ~N[2000-01-01 00:00:09] # Parse a &quot;C Time&quot; string. &gt; {:ok, ndt} = &quot;Wed Apr 9 07:53:03 2003&quot; |&gt; Calendar.NaiveDateTime.Parse.asctime {:ok, ~N[2003-04-09 07:53:03]} # Calendar.NaiveDateTime.Format.asctime can take a naive datetime and format it # as a as a C time string. We format the NaiveDateTime struct we just got from # parsing and get the same result as the original input: &gt; ndt |&gt; Calendar.NaiveDateTime.Format.asctime &quot;Wed Apr 9 07:53:03 2003&quot; # Compare with another naive datetime in the form of an erlang style datetime tuple # Returns the difference in seconds, microseconds and if it is before after or at the # same time &gt; ndt |&gt; Calendar.NaiveDateTime.diff({{2003, 4, 8}, {10, 0, 0}}) {:ok, 78783, 0, :after} # There are also boolean functions to just find out if a naive datetime is before or # after another one &gt; ndt |&gt; Calendar.NaiveDateTime.after?(~N[2003-04-08 10:00:00]) true"},{"ref":"readme.html#datetime-usage-examples","title":"Calendar - DateTime usage examples","type":"extras","doc":"The time right now for a specified time zone: cph = Calendar.DateTime.now! &quot;Europe/Copenhagen&quot; %DateTime{calendar: Calendar.ISO, day: 14, hour: 5, microsecond: {496149, 6}, minute: 27, month: 6, second: 14, std_offset: 3600, time_zone: &quot;Europe/Copenhagen&quot;, utc_offset: 3600, year: 2016, zone_abbr: &quot;CEST&quot;} Get a DateTime struct for the 4th of October 2014 at 23:44:32 in the city of Montevideo: {:ok, mvd} = Calendar.DateTime.from_erl {{2014,10,4},{23,44,32}}, &quot;America/Montevideo&quot; {:ok, %DateTime{calendar: Calendar.ISO, day: 4, hour: 23, microsecond: {0, 0}, minute: 44, month: 10, second: 32, std_offset: 0, time_zone: &quot;America/Montevideo&quot;, utc_offset: -10800, year: 2014, zone_abbr: &quot;-03&quot;}} A DateTime struct is now assigned to the variable mvd. Let&#39;s get a DateTime struct for the same time in the London time zone: london = mvd |&gt; Calendar.DateTime.shift_zone!(&quot;Europe/London&quot;) %DateTime{calendar: Calendar.ISO, day: 5, hour: 3, microsecond: {0, 0}, minute: 44, month: 10, second: 32, std_offset: 3600, time_zone: &quot;Europe/London&quot;, utc_offset: 0, year: 2014, zone_abbr: &quot;BST&quot;} ...and then in UTC: london |&gt; Calendar.DateTime.shift_zone!(&quot;Etc/UTC&quot;) %DateTime{calendar: Calendar.ISO, day: 5, hour: 2, microsecond: {0, 0}, minute: 44, month: 10, second: 32, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2014, zone_abbr: &quot;UTC&quot;} Transforming a DateTime to a string in ISO 8601 / RFC 3339 format: &gt; mvd |&gt; Calendar.DateTime.Format.rfc3339 &quot;2014-10-04T23:44:32-03:00&quot; # or ISO 8601 basic &gt; mvd |&gt; Calendar.DateTime.Format.iso8601_basic &quot;20141004T234432-0300&quot; Format as a unix timestamp: mvd |&gt; Calendar.DateTime.Format.unix 1412477072 Format as milliseconds that can be used by JavaScript: mvd |&gt; Calendar.DateTime.Format.js_ms 1412477072000 # Can be used like this in Javascript: new Date(1412477072000) Parsing an RFC 3339 timestamp as UTC: {:ok, parsed} = Calendar.DateTime.Parse.rfc3339_utc &quot;2014-10-04T23:44:32.4999Z&quot; {:ok, %DateTime{calendar: Calendar.ISO, day: 4, hour: 23, microsecond: {499900, 4}, minute: 44, month: 10, second: 32, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2014, zone_abbr: &quot;UTC&quot;}} # Format the parsed DateTime as ISO 8601 Basic parsed |&gt; Calendar.DateTime.Format.iso8601_basic &quot;20141004T234432Z&quot; Transform a DateTime struct to an Erlang style tuple: cph |&gt; Calendar.DateTime.to_erl {{2016, 6, 14}, {5, 27, 14}} Make a new %DateTime{} struct in the future from a tuple by adding 1800 seconds. Calendar.DateTime.from_erl!({{2014,10,4},{23,44,32}}, &quot;Europe/Oslo&quot;) |&gt; Calendar.DateTime.add(1800) {:ok, %DateTime{calendar: Calendar.ISO, day: 5, hour: 0, microsecond: {0, 0}, minute: 14, month: 10, second: 32, std_offset: 3600, time_zone: &quot;Europe/Oslo&quot;, utc_offset: 3600, year: 2014, zone_abbr: &quot;CEST&quot;}} Create DateTime struct from :os.timestamp / erlang &quot;now&quot; format: &gt; {1457, 641101, 48030} |&gt; Calendar.DateTime.from_erlang_timestamp %DateTime{calendar: Calendar.ISO, day: 10, hour: 20, microsecond: {48030, 6}, minute: 18, month: 3, second: 21, std_offset: 0, time_zone: &quot;Etc/UTC&quot;, utc_offset: 0, year: 2016, zone_abbr: &quot;UTC&quot;}"},{"ref":"readme.html#documentation","title":"Calendar - Documentation","type":"extras","doc":"Documentation can be found at http://hexdocs.pm/calendar/"},{"ref":"readme.html#elixir-versions-earlier-than-1-3","title":"Calendar - Elixir versions earlier than 1.3","type":"extras","doc":"If you are using an Elixir version earlier than 1.3, use Calendar version ~&gt; 0.14.2 This version accepts the Calendar structs from earlier versions (e.g. %Calendar.DateTime) And additionally when running on Elixir 1.3 or higher, it accepts the built in calendar types present in Elixir 1.3 (e.g. %DateTime). But Calendar structs are always returned."},{"ref":"readme.html#raison-dêtre","title":"Calendar - Raison d&#39;être","type":"extras","doc":"The purpose of Calendar is to have an easy to use library for handling dates, time and datetimes that gives correct results. Instead of treating everything as a datetime, the different types (Date, Time, NaiveDateTime, DateTime) provide clarity and safety from certain bugs. Before Calendar, there was no Elixir library with correct time zone support. The timezone information was later extracted from Calendar into the Tzdata library."},{"ref":"readme.html#video-presentation-with-some-calendar-examples","title":"Calendar - Video presentation with some Calendar examples","type":"extras","doc":"In a talk from ElixirConf 2015 Calendar is featured. Specifically from around 27:07 into the video there are some Calendar examples."},{"ref":"readme.html#trouble-shooting","title":"Calendar - Trouble shooting","type":"extras","doc":"Problem: an error like this occours: ** (exit) an exception was raised: ** (ArgumentError) argument error (stdlib) :ets.lookup(:tzdata_current_release, :release_version) lib/tzdata/release_reader.ex:41: Tzdata.ReleaseReader.current_release_from_table/0 lib/tzdata/release_reader.ex:13: Tzdata.ReleaseReader.simple_lookup/1 Solution: add :calendar to the application list in the mix.exs file of your project."},{"ref":"readme.html#license","title":"Calendar - License","type":"extras","doc":"Calendar is released under the MIT license. See the LICENSE file."}]